@@ -7,7 +7,7 @@
  * Description : Qt Model for Albums - drag and drop handling
  *
  * SPDX-FileCopyrightText: 2005-2006 by Joern Ahrens <joern dot ahrens at kdemail dot net>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2009      by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
@@ -85,19 +85,22 @@ bool AlbumDragDropHandler::dropEvent(QAbstractItemView* view,
             return false;
         }
 
-        // TODO Copy?
-
         QMenu popMenu(view);
-        QAction* const moveAction = popMenu.addAction(QIcon::fromTheme(QLatin1String("go-jump")), i18n("&Move Here"));
+        QAction* const moveAction = popMenu.addAction(QIcon::fromTheme(QLatin1String("go-jump")),   i18n("&Move Here"));
+        QAction* const copyAction = popMenu.addAction(QIcon::fromTheme(QLatin1String("edit-copy")), i18n("&Copy Here"));
         popMenu.addSeparator();
         popMenu.addAction(QIcon::fromTheme(QLatin1String("dialog-cancel")), i18n("C&ancel"));
         popMenu.setMouseTracking(true);
         QAction* const choice     = popMenu.exec(QCursor::pos());
 
-        if (choice == moveAction)
+        if      (choice == moveAction)
         {
             DIO::move(droppedAlbum, destAlbum);
         }
+        else if (choice == copyAction)
+        {
+            DIO::copy(droppedAlbum, destAlbum);
+        }
 
         return true;
     }
@@ -141,11 +144,16 @@ bool AlbumDragDropHandler::dropEvent(QAbstractItemView* view,
 
             bool set = false;
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
             if (e->modifiers() == Qt::ControlModifier)
+
 #else
+
             if (e->keyboardModifiers() == Qt::ControlModifier)
+
 #endif
+
             {
                 set = true;
             }
@@ -179,22 +187,33 @@ bool AlbumDragDropHandler::dropEvent(QAbstractItemView* view,
         bool ddCopy       = false;
         bool setThumbnail = false;
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
         if      (e->modifiers() == Qt::ShiftModifier)
+
 #else
+
         if      (e->keyboardModifiers() == Qt::ShiftModifier)
+
 #endif
+
         {
             // If shift key is pressed while dragging, move the drag object without
             // displaying popup menu -> move
 
             ddMove = true;
         }
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
         else if (e->modifiers() == Qt::ControlModifier)
+
 #else
+
         else if (e->keyboardModifiers() == Qt::ControlModifier)
+
 #endif
+
         {
             // If ctrl key is pressed while dragging, copy the drag object without
             // displaying popup menu -> copy
@@ -295,22 +314,33 @@ bool AlbumDragDropHandler::dropEvent(QAbstractItemView* view,
         bool ddMove         = false;
         bool ddCopy         = false;
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
         if      (e->modifiers() == Qt::ShiftModifier)
+
 #else
+
         if      (e->keyboardModifiers() == Qt::ShiftModifier)
+
 #endif
+
         {
             // If shift key is pressed while dropping, move the drag object without
             // displaying popup menu -> move
 
             ddMove = true;
         }
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
         else if (e->modifiers() == Qt::ControlModifier)
+
 #else
+
         else if (e->keyboardModifiers() == Qt::ControlModifier)
+
 #endif
+
         {
             // If ctrl key is pressed while dropping, copy the drag object without
             // displaying popup menu -> copy
@@ -449,3 +479,5 @@ QMimeData* AlbumDragDropHandler::createMimeData(const QList<Album*>& albums)
 }
 
 } // namespace Digikam
+
+#include "moc_albumdragdrop.cpp"
