@@ -6,32 +6,24 @@
  * Date        : 2009-12-05
  * Description : Side Bar Widget for People
  *
- * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * Copyright (C) 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
+ * SPDX-FileCopyrightText: 2024      by Michael Miller <michael underscore miller at msn dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_PEOPLE_SIDE_BAR_WIDGET_H
-#define DIGIKAM_PEOPLE_SIDE_BAR_WIDGET_H
+#pragma once
 
 // Local includes
 
 #include "albummodel.h"
 #include "searchmodificationhelper.h"
 #include "sidebarwidget.h"
+#include "facescansettings.h"
 
 namespace Digikam
 {
@@ -45,7 +37,7 @@ public:
     explicit PeopleSideBarWidget(QWidget* const parent,
                                  TagModel* const tagModel,
                                  SearchModificationHelper* const searchModificationHelper);
-    ~PeopleSideBarWidget() override;
+    ~PeopleSideBarWidget()                                           override;
 
     void          setActive(bool active)                             override;
     void          doLoadState()                                      override;
@@ -55,6 +47,8 @@ public:
     const QIcon   getIcon()                                          override;
     const QString getCaption()                                       override;
 
+    static void   doFaceScan(const FaceScanSettings& faceScanSettings);
+
 private Q_SLOTS:
 
     void slotInit();
@@ -69,9 +63,7 @@ Q_SIGNALS:
 private:
 
     class Private;
-    Private* const d;
+    static Private* d;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_PEOPLE_SIDE_BAR_WIDGET_H
