@@ -79,14 +79,19 @@ void ItemIconView::slotImageScanForFaces()
 
     // TODO Faces engine : set K-nearest config
 
-    settings.accuracy               = ApplicationSettings::instance()->getFaceDetectionAccuracy();
-    settings.useYoloV3              = ApplicationSettings::instance()->getFaceDetectionYoloV3();
+    settings.detectAccuracy         = ApplicationSettings::instance()->getFaceDetectionAccuracy();
+    settings.detectModel            = ApplicationSettings::instance()->getFaceDetectionModel();
+    settings.detectSize             = ApplicationSettings::instance()->getFaceDetectionSize();
+    settings.recognizeAccuracy      = ApplicationSettings::instance()->getFaceRecognitionAccuracy();
+    settings.recognizeModel         = ApplicationSettings::instance()->getFaceRecognitionModel();
     settings.task                   = FaceScanSettings::Detect;
     settings.alreadyScannedHandling = FaceScanSettings::Rescan;
 
     // Remove possible duplicate ItemInfos.
 
-    Q_FOREACH (const ItemInfo& info, selectedInfoList(ToolsOps))
+    const auto infs = selectedInfoList(ToolsOps);
+
+    for (const ItemInfo& info : infs)
     {
         if (!settings.infos.contains(info))
         {
@@ -120,13 +125,18 @@ void ItemIconView::slotImageRecognizeFaces()
 
     // TODO Faces engine : set K-nearest config
 
-    settings.accuracy  = ApplicationSettings::instance()->getFaceDetectionAccuracy();
-    settings.useYoloV3 = ApplicationSettings::instance()->getFaceDetectionYoloV3();
-    settings.task      = FaceScanSettings::RecognizeMarkedFaces;
+    settings.detectAccuracy    = ApplicationSettings::instance()->getFaceDetectionAccuracy();
+    settings.detectModel       = ApplicationSettings::instance()->getFaceDetectionModel();
+    settings.detectSize        = ApplicationSettings::instance()->getFaceDetectionSize();
+    settings.recognizeAccuracy = ApplicationSettings::instance()->getFaceRecognitionAccuracy();
+    settings.recognizeModel    = ApplicationSettings::instance()->getFaceRecognitionModel();
+    settings.task              = FaceScanSettings::RecognizeMarkedFaces;
 
     // Remove possible duplicate ItemInfos.
 
-    Q_FOREACH (const ItemInfo& info, selectedInfoList(ToolsOps))
+    const auto infs = selectedInfoList(ToolsOps);
+
+    for (const ItemInfo& info : infs)
     {
         if (!settings.infos.contains(info))
         {
