@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CONVERT_8_TO_16_PLUGIN_H
-#define DIGIKAM_CONVERT_8_TO_16_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class Convert8To16Plugin : public DPluginBqm
 public:
 
     explicit Convert8To16Plugin(QObject* const parent = nullptr);
-    ~Convert8To16Plugin()                override;
+    ~Convert8To16Plugin()                override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmConvert8To16Plugin
-
-#endif // DIGIKAM_CONVERT_8_TO_16_PLUGIN_H
