@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CONVERT_TO_TIFF_H
-#define DIGIKAM_BQM_CONVERT_TO_TIFF_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ class ConvertToTIFF : public BatchTool
 public:
 
     explicit ConvertToTIFF(QObject* const parent = nullptr);
-    ~ConvertToTIFF()                                        override;
+    ~ConvertToTIFF()                                        override = default;
 
     QString outputSuffix()                            const override;
     BatchToolSettings defaultSettings()                     override;
@@ -51,9 +50,7 @@ private:
 
 private:
 
-    bool m_changeSettings;
+    bool m_changeSettings = true;
 };
 
 } // namespace DigikamBqmConvertToTiffPlugin
-
-#endif // DIGIKAM_BQM_CONVERT_TO_TIFF_H
