@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TEXTURE_PLUGIN_H
-#define DIGIKAM_TEXTURE_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class TexturePlugin : public DPluginBqm
 public:
 
     explicit TexturePlugin(QObject* const parent = nullptr);
-    ~TexturePlugin()                     override;
+    ~TexturePlugin()                     override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmTexturePlugin
-
-#endif // DIGIKAM_TEXTURE_PLUGIN_H
