@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_RESTORATION_PLUGIN_H
-#define DIGIKAM_RESTORATION_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class RestorationPlugin : public DPluginBqm
 public:
 
     explicit RestorationPlugin(QObject* const parent = nullptr);
-    ~RestorationPlugin()                 override;
+    ~RestorationPlugin()                 override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmRestorationPlugin
-
-#endif // DIGIKAM_RESTORATION_PLUGIN_H
