@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_FILM_GRAIN_PLUGIN_H
-#define DIGIKAM_FILM_GRAIN_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class FilmGrainPlugin : public DPluginBqm
 public:
 
     explicit FilmGrainPlugin(QObject* const parent = nullptr);
-    ~FilmGrainPlugin()                   override;
+    ~FilmGrainPlugin()                   override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmFilmGrainPlugin
-
-#endif // DIGIKAM_FILM_GRAIN_PLUGIN_H
