@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_ASSIGN_LABELS_H
-#define DIGIKAM_BQM_ASSIGN_LABELS_H
+#pragma once
 
 // Local includes
 
@@ -51,9 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamBqmAssignLabelsPlugin
-
-#endif // DIGIKAM_BQM_ASSIGN_LABELS_H
