@@ -20,8 +20,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_HEIF_LOADER_H
-#define DIGIKAM_DIMG_HEIF_LOADER_H
+#pragma once
 
 // Libheif includes
 
@@ -43,7 +42,7 @@ class DImgHEIFLoader : public DImgLoader
 public:
 
     explicit DImgHEIFLoader(DImg* const image);
-    ~DImgHEIFLoader()                                                      override;
+    ~DImgHEIFLoader()                                                      override = default;
 
     bool load(const QString& filePath, DImgLoaderObserver* const observer) override;
     bool save(const QString& filePath, DImgLoaderObserver* const observer) override;
@@ -87,5 +86,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DIMG_HEIF_LOADER_H
