@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SHEARTOOL_PLUGIN_H
-#define DIGIKAM_SHEARTOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class ShearToolPlugin : public DPluginEditor
 public:
 
     explicit ShearToolPlugin(QObject* const parent = nullptr);
-    ~ShearToolPlugin()                   override;
+    ~ShearToolPlugin()                   override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorShearToolPlugin
-
-#endif // DIGIKAM_SHEARTOOL_PLUGIN_H
