@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SCAN_DIALOG_H
-#define DIGIKAM_SCAN_DIALOG_H
+#pragma once
 
 // Qt includes
 
@@ -81,9 +80,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericDScannerPlugin
-
-#endif // DIGIKAM_SCAN_DIALOG_H
