@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EXIF_EDIT_WIDGET_H
-#define DIGIKAM_EXIF_EDIT_WIDGET_H
+#pragma once
 
 // Local includes
 
@@ -34,9 +33,9 @@ class EXIFEditWidget : public DConfigDlgWdg
 public:
 
     explicit EXIFEditWidget(MetadataEditDialog* const parent);
-    ~EXIFEditWidget() override;
+    ~EXIFEditWidget()             override;
 
-    bool isModified() const;
+    bool isModified()       const;
     void saveSettings();
     void apply();
 
@@ -54,15 +53,13 @@ private:
 
     void readSettings();
 
-    int  activePageIndex() const;
+    int  activePageIndex()  const;
     void showPage(int page);
 
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericMetadataEditPlugin
-
-#endif // DIGIKAM_EXIF_EDIT_WIDGET_H
