@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EXIF_LIGHT_H
-#define DIGIKAM_EXIF_LIGHT_H
+#pragma once
 
 // Qt includes
 
@@ -48,9 +47,7 @@ Q_SIGNALS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericMetadataEditPlugin
-
-#endif // DIGIKAM_EXIF_LIGHT_H
