@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_XMP_SUBJECTS_H
-#define DIGIKAM_XMP_SUBJECTS_H
+#pragma once
 
 // Qt includes
 
@@ -37,12 +36,10 @@ class XMPSubjects : public SubjectWidget
 public:
 
     explicit XMPSubjects(QWidget* const parent);
-    ~XMPSubjects() override;
+    ~XMPSubjects() override = default;
 
     void applyMetadata(const DMetadata& meta);
     void readMetadata(const DMetadata& meta);
 };
 
 } // namespace DigikamGenericMetadataEditPlugin
-
-#endif // DIGIKAM_XMP_SUBJECTS_H
