@@ -45,14 +45,7 @@ namespace DigikamGenericMjpegStreamPlugin
 {
 
 MjpegServer::Private::Private(QObject* const parent)
-    : QObject(parent),
-      server (nullptr),
-      rate   (15),
-      delay  (40000)
-{
-}
-
-MjpegServer::Private::~Private()
+    : QObject(parent)
 {
 }
 
@@ -249,7 +242,7 @@ void MjpegServer::Private::writerThread()
         {
             mutexClients.lock();
             {
-                Q_FOREACH (QTcpSocket* const client, clients)
+                for (QTcpSocket* const client : std::as_const(clients))
                 {
                     sockTasks.append(QtConcurrent::run(
 
@@ -270,7 +263,7 @@ void MjpegServer::Private::writerThread()
             }
             mutexClients.unlock();
 
-            Q_FOREACH (QFuture<void> t, sockTasks)
+            for (QFuture<void> t : std::as_const(sockTasks))
             {
                 t.waitForFinished();
             }
