@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_MJPEG_SERVER_MNGR_H
-#define DIGIKAM_MJPEG_SERVER_MNGR_H
+#pragma once
 
 // Qt includes
 
@@ -130,9 +129,7 @@ private:
     friend class MjpegServerMngrCreator;
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericMjpegStreamPlugin
-
-#endif // DIGIKAM_MJPEG_SERVER_MNGR_H
