@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ADV_PRINT_INTRO_PAGE_H
-#define DIGIKAM_ADV_PRINT_INTRO_PAGE_H
+#pragma once
 
 // Qt includes
 
@@ -43,9 +42,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericPrintCreatorPlugin
-
-#endif // DIGIKAM_ADV_PRINT_INTRO_PAGE_H
