@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_MAIL_ALBUMS_PAGE_H
-#define DIGIKAM_MAIL_ALBUMS_PAGE_H
+#pragma once
 
 // Qt includes
 
@@ -45,9 +44,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericSendByMailPlugin
-
-#endif // DIGIKAM_MAIL_ALBUMS_PAGE_H
