@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GLVIEWER_PLUGIN_GLVIEWER_TEXTURE_H
-#define DIGIKAM_GLVIEWER_PLUGIN_GLVIEWER_TEXTURE_H
+#pragma once
 
 // Qt includes
 
@@ -38,7 +37,7 @@ class GLViewerTexture : public QOpenGLTexture
 public:
 
     explicit GLViewerTexture(DInfoInterface* const iface, QWidget* const display);
-    ~GLViewerTexture();
+    virtual ~GLViewerTexture();
 
     bool load(const QString& fn, const QSize& size);
     bool load(const QImage& im);
@@ -70,9 +69,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericGLViewerPlugin
-
-#endif // DIGIKAM_GLVIEWER_PLUGIN_GLVIEWER_TEXTURE_H
