@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SLIDE_ERROR_PLUGIN_H
-#define DIGIKAM_SLIDE_ERROR_PLUGIN_H
+#pragma once
 
 // Qt includes
 
@@ -42,9 +41,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericSlideShowPlugin
-
-#endif // DIGIKAM_SLIDE_ERROR_PLUGIN_H
