@@ -38,7 +38,6 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "digikam_globals.h"
 
 namespace DigikamGenericMediaWikiPlugin
 {
@@ -47,15 +46,11 @@ class Q_DECL_HIDDEN MediaWikiTalker::Private
 {
 public:
 
-    explicit Private()
-    {
-        interface = nullptr;
-        MediaWiki = nullptr;
-    }
+    Private() = default;
 
     QList<QUrl>                              urls;
-    DInfoInterface*                          interface;
-    Iface*                                   MediaWiki;
+    DInfoInterface*                          interface      = nullptr;
+    Iface*                                   MediaWiki      = nullptr;
     QString                                  error;
     QString                                  currentFile;
     QMap <QString, QMap <QString, QString> > imageDesc;
@@ -97,6 +92,7 @@ void MediaWikiTalker::slotUploadHandle(KJob* j)
     if (j != nullptr)
     {
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Upload error" << j->error() << j->errorString() << j->errorText();
+
         Q_EMIT signalUploadProgress(100);
 
         disconnect(j, SIGNAL(result(KJob*)),
@@ -235,7 +231,7 @@ QString MediaWikiTalker::buildWikiText(const QMap<QString, QString>& info) const
 
     if (!info[QLatin1String("categories")].isEmpty())
     {
-        categories = info[QLatin1String("categories")].split(QLatin1Char('\n'), QT_SKIP_EMPTY_PARTS);
+        categories = info[QLatin1String("categories")].split(QLatin1Char('\n'), Qt::SkipEmptyParts);
 
         for (int i = 0 ; i < categories.size() ; ++i)
         {
@@ -245,7 +241,7 @@ QString MediaWikiTalker::buildWikiText(const QMap<QString, QString>& info) const
 
     if (!info[QLatin1String("genCategories")].isEmpty())
     {
-        categories = info[QLatin1String("genCategories")].split(QLatin1Char('\n'), QT_SKIP_EMPTY_PARTS);
+        categories = info[QLatin1String("genCategories")].split(QLatin1Char('\n'), Qt::SkipEmptyParts);
 
         for (int i = 0 ; i < categories.size() ; ++i)
         {
@@ -259,6 +255,7 @@ QString MediaWikiTalker::buildWikiText(const QMap<QString, QString>& info) const
 void MediaWikiTalker::slotUploadProgress(KJob* job, unsigned long percent)
 {
     Q_UNUSED(job)
+
     Q_EMIT signalUploadProgress((int)percent);
 }
 
