@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_WS_SETTINGS_PAGE_H
-#define DIGIKAM_WS_SETTINGS_PAGE_H
+#pragma once
 
 // Qt includes
 
@@ -47,9 +46,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericUnifiedPlugin
-
-#endif // DIGIKAM_WS_SETTINGS_PAGE_H
