@@ -50,17 +50,14 @@ class Q_DECL_HIDDEN AlbumModificationHelper::Private
 {
 public:
 
-    explicit Private()
-      : dialogParent(nullptr)
-    {
-    }
+    Private() = default;
 
-    QWidget*     dialogParent;
+    QWidget* dialogParent = nullptr;
 };
 
 AlbumModificationHelper::AlbumModificationHelper(QObject* const parent, QWidget* const dialogParent)
     : QObject(parent),
-      d(new Private)
+      d      (new Private)
 {
     d->dialogParent = dialogParent;
 }
@@ -309,9 +306,8 @@ void AlbumModificationHelper::slotAlbumRename(PAlbum* album)
     {
         if (album->isAlbumRoot())
         {
-            CollectionLocation location =
-                CollectionManager::instance()->
-                    locationForAlbumRootId(album->albumRootId());
+            CollectionLocation location = CollectionManager::instance()->
+                                          locationForAlbumRootId(album->albumRootId());
 
             if (!location.isNull())
             {
