@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ALBUM_WATCH_H
-#define DIGIKAM_ALBUM_WATCH_H
+#pragma once
 
 // Qt includes
 
@@ -56,9 +55,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ALBUM_WATCH_H
