@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ALBUM_SELECTION_TREE_VIEW_H
-#define DIGIKAM_ALBUM_SELECTION_TREE_VIEW_H
+#pragma once
 
 // Qt includes
 
@@ -81,9 +80,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ALBUM_SELECTION_TREE_VIEW_H
