@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TAG_TREE_VIEW_H
-#define DIGIKAM_TAG_TREE_VIEW_H
+#pragma once
 
 // Local includes
 
@@ -31,18 +30,21 @@ class TagTreeView : public AbstractCheckableAlbumTreeView
 public:
 
     explicit TagTreeView(QWidget* const parent = nullptr, Flags flags = DefaultFlags);
-    ~TagTreeView() override;
+    ~TagTreeView() override = default;
 
-    TagModel* albumModel() const;
-
-    /// Contains only the tags filtered by properties - prefer to albumModel()
-    TagPropertiesFilterModel* filteredModel() const;
+    TagModel* albumModel()                          const;
 
     /**
-     * @brief currentAlbum     - even if multiple selection is enabled current
-     *                           Album can be only one, the last clicked item
-     *                          if you need selected items, see selectedAlbums()
-     *                          It's NOT the same as AlbumManager::currentAlbums()
+     * Contains only the tags filtered by properties - prefer to albumModel()
+     */
+    TagPropertiesFilterModel* filteredModel()       const;
+
+    /**
+     * @brief currentAlbum
+     * Even if multiple selection is enabled current
+     * Album can be only one, the last clicked item
+     * if you need selected items, see selectedAlbums()
+     * It's NOT the same as AlbumManager::currentAlbums()
      */
     TAlbum* currentAlbum() const;
 
@@ -69,10 +71,8 @@ Q_SIGNALS:
 
 protected:
 
-    TagPropertiesFilterModel* m_filteredModel;
-    TagModificationHelper*    m_modificationHelper;
+    TagPropertiesFilterModel* m_filteredModel       = nullptr;
+    TagModificationHelper*    m_modificationHelper  = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TAG_TREE_VIEW_H
