@@ -7,7 +7,7 @@
  * Description : A widget to select Physical or virtual albums with combo-box
  *
  * SPDX-FileCopyrightText: 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -68,52 +68,42 @@ class Q_DECL_HIDDEN AlbumSelectors::Private
 {
 public:
 
-    explicit Private()
-      : albumSelectCB   (nullptr),
-        tagSelectCB     (nullptr),
-        albumClearButton(nullptr),
-        tagClearButton  (nullptr),
-        wholeAlbums     (nullptr),
-        wholeTags       (nullptr),
-        tabWidget       (nullptr),
-        albumWidget     (nullptr),
-        tagWidget       (nullptr),
-        selectionMode   (All)
-    {
-    }
+    Private() = default;
 
-    static const QString         configUseWholeAlbumsEntry;
-    static const QString         configUseWholeTagsEntry;
-    static const QString         configAlbumTypeEntry;
+    const QString configUseWholeAlbumsEntry                 = QLatin1String("UseWholeAlbumsEntry");
+    const QString configUseWholeTagsEntry                   = QLatin1String("UseWholeTagsEntry");
+    const QString configAlbumTypeEntry                      = QLatin1String("AlbumTypeEntry");
 
     QString                      configName;
 
-    AlbumTreeViewSelectComboBox* albumSelectCB;
-    TagTreeViewSelectComboBox*   tagSelectCB;
-    ModelClearButton*            albumClearButton;
-    ModelClearButton*            tagClearButton;
+    AlbumTreeViewSelectComboBox* albumSelectCB              = nullptr;
+    TagTreeViewSelectComboBox*   tagSelectCB                = nullptr;
+    ModelClearButton*            albumClearButton           = nullptr;
+    ModelClearButton*            tagClearButton             = nullptr;
 
-    QCheckBox*                   wholeAlbums;
-    QCheckBox*                   wholeTags;
+    QCheckBox*                   recursiveSelectionAlbum    = nullptr;
+    QCheckBox*                   wholeAlbums                = nullptr;
+    QCheckBox*                   recursiveSelectionTags     = nullptr;
+    QCheckBox*                   wholeTags                  = nullptr;
 
-    QTabWidget*                  tabWidget;
-    QWidget*                     albumWidget;
-    QWidget*                     tagWidget;
+    QTabWidget*                  tabWidget                  = nullptr;
+    QWidget*                     albumWidget                = nullptr;
+    QWidget*                     tagWidget                  = nullptr;
 
-    AlbumType                    selectionMode;
+    AlbumType                    selectionMode              = All;
+
+    bool                         allowRecursive             = false;
 };
 
-const QString AlbumSelectors::Private::configUseWholeAlbumsEntry(QLatin1String("UseWholeAlbumsEntry"));
-const QString AlbumSelectors::Private::configUseWholeTagsEntry(QLatin1String("UseWholeTagsEntry"));
-const QString AlbumSelectors::Private::configAlbumTypeEntry(QLatin1String("AlbumTypeEntry"));
-
 AlbumSelectors::AlbumSelectors(const QString& label,
                                const QString& configName,
                                QWidget* const parent,
-                               AlbumType albumType)
+                               AlbumType albumType,
+                               bool allowRecursive)
     : QWidget(parent),
       d      (new Private)
 {
+    d->allowRecursive             = allowRecursive;
     d->configName                 = configName;
     setObjectName(d->configName);
 
@@ -167,22 +157,42 @@ AlbumSelectors::~AlbumSelectors()
 
 void AlbumSelectors::initAlbumWidget()
 {
-    d->albumWidget   = new QWidget(this);
-    d->wholeAlbums   = new QCheckBox(i18nc("@option", "Whole albums collection"), d->albumWidget);
-    d->albumSelectCB = new AlbumTreeViewSelectComboBox(d->albumWidget);
+    d->albumWidget             = new QWidget(this);
+    d->wholeAlbums             = new QCheckBox(i18nc("@option", "All albums"), d->albumWidget);
+    d->recursiveSelectionAlbum = new QCheckBox(i18nc("@option", "Recursive"), d->albumWidget);
+    d->recursiveSelectionAlbum->setToolTip(i18nc("@info:tooltip", "Recursive selection."));
+    d->recursiveSelectionAlbum->setChecked(true);
+
+    if (!d->allowRecursive)
+    {
+        d->recursiveSelectionAlbum->setVisible(false);
+        d->recursiveSelectionAlbum->setChecked(false);
+    }
+
+    d->albumSelectCB    = new AlbumTreeViewSelectComboBox(d->albumWidget);
     d->albumSelectCB->setToolTip(i18nc("@info:tooltip", "Select all albums that should be processed."));
     d->albumSelectCB->setDefaultModel();
+    d->albumSelectCB->setRecursive(d->allowRecursive ? d->recursiveSelectionAlbum->isChecked() : false);
     d->albumSelectCB->setNoSelectionText(i18nc("@info", "No Album Selected"));
+/*
+    d->albumSelectCB->setAddExcludeTristate(true);
+*/
     d->albumSelectCB->addCheckUncheckContextMenuActions();
 
     d->albumClearButton = new ModelClearButton(d->albumSelectCB->view()->albumModel());
     d->albumClearButton->setToolTip(i18nc("@info:tooltip", "Reset selected albums"));
 
+    QHBoxLayout* l      = new QHBoxLayout;
+    l->addWidget(d->wholeAlbums);
+    l->addWidget(d->recursiveSelectionAlbum);
+    l->addItem(new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding));
+
     QGridLayout* const pAlbumsGrid = new QGridLayout(d->albumWidget);
-    pAlbumsGrid->addWidget(d->wholeAlbums,      0, 0, 1, 2);
+    pAlbumsGrid->addLayout(l,                   0, 0, 1, 2);
     pAlbumsGrid->addWidget(d->albumSelectCB,    1, 0, 1, 1);
     pAlbumsGrid->addWidget(d->albumClearButton, 1, 1, 1, 1);
     pAlbumsGrid->setSpacing(0);
+    pAlbumsGrid->setRowStretch(2, 10);
 
     connect(d->wholeAlbums, SIGNAL(toggled(bool)),
             this, SLOT(slotWholeAlbums(bool)));
@@ -190,6 +200,13 @@ void AlbumSelectors::initAlbumWidget()
     connect(d->wholeAlbums, SIGNAL(toggled(bool)),
             this, SIGNAL(signalSelectionChanged()));
 
+    connect(d->recursiveSelectionAlbum, &QCheckBox::clicked,
+            d->recursiveSelectionAlbum, [this] (bool checked)
+        {
+            d->albumSelectCB->setRecursive(checked);
+        }
+    );
+
     connect(d->albumSelectCB->view()->albumModel(), SIGNAL(checkStateChanged(Album*,Qt::CheckState)),
             this, SLOT(slotUpdateClearButtons()));
 
@@ -200,22 +217,39 @@ void AlbumSelectors::initAlbumWidget()
 
 void AlbumSelectors::initTagWidget()
 {
-    d->tagWidget   = new QWidget(this);
-    d->wholeTags   = new QCheckBox(i18nc("@option", "Whole tags collection"), d->tagWidget);
-    d->tagSelectCB = new TagTreeViewSelectComboBox(d->tagWidget);
+    d->tagWidget              = new QWidget(this);
+    d->wholeTags              = new QCheckBox(i18nc("@option", "All tags"), d->tagWidget);
+    d->recursiveSelectionTags = new QCheckBox(i18nc("@option", "Recursive"), d->albumWidget);
+    d->recursiveSelectionTags->setToolTip(i18nc("@info:tooltip", "Recursive selection."));
+    d->recursiveSelectionTags->setChecked(true);
+
+    if (!d->allowRecursive)
+    {
+        d->recursiveSelectionTags->setVisible(false);
+        d->recursiveSelectionTags->setChecked(false);
+    }
+
+    d->tagSelectCB    = new TagTreeViewSelectComboBox(d->tagWidget);
     d->tagSelectCB->setToolTip(i18nc("@info:tooltip", "Select all tags that should be processed."));
     d->tagSelectCB->setDefaultModel();
+    d->tagSelectCB->setRecursive(d->allowRecursive ? d->recursiveSelectionTags->isChecked() : false);
     d->tagSelectCB->setNoSelectionText(i18nc("@info", "No Tag Selected"));
     d->tagSelectCB->addCheckUncheckContextMenuActions();
 
     d->tagClearButton = new ModelClearButton(d->tagSelectCB->view()->albumModel());
     d->tagClearButton->setToolTip(i18nc("@info:tooltip", "Reset selected tags"));
 
+    QHBoxLayout* l    = new QHBoxLayout;
+    l->addWidget(d->wholeTags);
+    l->addWidget(d->recursiveSelectionTags);
+    l->addItem(new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding));
+
     QGridLayout* const tAlbumsGrid = new QGridLayout(d->tagWidget);
-    tAlbumsGrid->addWidget(d->wholeTags,      0, 0, 1, 2);
+    tAlbumsGrid->addLayout(l,                 0, 0, 1, 2);
     tAlbumsGrid->addWidget(d->tagSelectCB,    1, 0, 1, 1);
     tAlbumsGrid->addWidget(d->tagClearButton, 1, 1, 1, 1);
     tAlbumsGrid->setSpacing(0);
+    tAlbumsGrid->setRowStretch(2, 10);
 
     connect(d->wholeTags, SIGNAL(toggled(bool)),
             this, SIGNAL(signalSelectionChanged()));
@@ -226,10 +260,16 @@ void AlbumSelectors::initTagWidget()
     connect(d->tagSelectCB->view()->albumModel(), SIGNAL(checkStateChanged(Album*,Qt::CheckState)),
             this, SLOT(slotUpdateClearButtons()));
 
+    connect(d->recursiveSelectionTags, &QCheckBox::clicked,
+            d->recursiveSelectionTags, [this] (bool checked)
+        {
+            d->tagSelectCB->setRecursive(checked);
+        }
+    );
+
     d->tagSelectCB->view()->setObjectName(d->configName);
     d->tagSelectCB->view()->setEntryPrefix(QLatin1String("TagComboBox-"));
     d->tagSelectCB->view()->setRestoreCheckState(true);
-
 }
 
 void AlbumSelectors::slotWholeAlbums(bool b)
@@ -238,6 +278,7 @@ void AlbumSelectors::slotWholeAlbums(bool b)
     {
         d->albumSelectCB->setEnabled(!b);
         d->albumClearButton->setEnabled(!b);
+        d->albumSelectCB->setAllSelectedText(b);
     }
 
     updateTabText();
@@ -249,6 +290,7 @@ void AlbumSelectors::slotWholeTags(bool b)
     {
         d->tagSelectCB->setEnabled(!b);
         d->tagClearButton->setEnabled(!b);
+        d->tagSelectCB->setAllSelectedText(b);
     }
 
     updateTabText();
@@ -304,7 +346,7 @@ QList<int> AlbumSelectors::selectedAlbumIds() const
     QList<int> albumIds;
     AlbumList  albums = selectedAlbums();
 
-    Q_FOREACH (Album* const album, albums)
+    for (Album* const album : std::as_const(albums))
     {
         albumIds << album->id();
     }
@@ -338,7 +380,7 @@ QList<int> AlbumSelectors::selectedTagIds() const
     QList<int> tagIds;
     AlbumList  tags = selectedTags();
 
-    Q_FOREACH (Album* const tag, tags)
+    for (Album* const tag : std::as_const(tags))
     {
         tagIds << tag->id();
     }
@@ -502,3 +544,5 @@ void AlbumSelectors::updateTabText()
 } // namespace Digikam
 
 #include "albumselectors.moc"
+
+#include "moc_albumselectors.cpp"
