@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2005-2006 by Tom Albers <tomalbers at kde dot nl>
  * SPDX-FileCopyrightText: 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -44,11 +44,6 @@ bool s_modificationDateEquals(const QDateTime& a, const QDateTime& b)
 
 // --------------------------------------------------------------------
 
-NewlyAppearedFile::NewlyAppearedFile()
-    : albumId(0)
-{
-}
-
 NewlyAppearedFile::NewlyAppearedFile(int albumId, const QString& fileName)
     : albumId (albumId),
       fileName(fileName)
@@ -58,7 +53,7 @@ NewlyAppearedFile::NewlyAppearedFile(int albumId, const QString& fileName)
 bool NewlyAppearedFile::operator==(const NewlyAppearedFile& other) const
 {
     return (
-            (albumId  == other.albumId) &&
+            (albumId  == other.albumId ) &&
             (fileName == other.fileName)
            );
 }
@@ -116,9 +111,9 @@ void CollectionScannerHintContainerImplementation::recordHints(const QList<Album
 {
     QWriteLocker locker(&lock);
 
-    Q_FOREACH (const AlbumCopyMoveHint& hint, hints)
+    for (const AlbumCopyMoveHint& hint : std::as_const(hints))
     {
-        // automagic casting to src and dst
+        // auto-magic casting to src and dst
 
         albumHints[hint] = hint;
     }
@@ -128,7 +123,7 @@ void CollectionScannerHintContainerImplementation::recordHints(const QList<ItemC
 {
     QWriteLocker locker(&lock);
 
-    Q_FOREACH (const ItemCopyMoveHint& hint, hints)
+    for (const ItemCopyMoveHint& hint : std::as_const(hints))
     {
         QList<qlonglong> ids = hint.srcIds();
         QStringList dstNames = hint.dstNames();
@@ -144,7 +139,7 @@ void CollectionScannerHintContainerImplementation::recordHints(const QList<ItemC
 {
     QWriteLocker locker(&lock);
 
-    Q_FOREACH (const ItemChangeHint& hint, hints)
+    for (const ItemChangeHint& hint : std::as_const(hints))
     {
         const QList<qlonglong>& ids = hint.ids();
 
@@ -170,7 +165,8 @@ void CollectionScannerHintContainerImplementation::recordHint(const ItemMetadata
 
         if (!
             (s_modificationDateEquals(hint.modificationDate(), info.modDateTime()) &&
-             (hint.fileSize() == info.fileSize()))
+             (hint.fileSize() == info.fileSize())
+            )
            )
         {
             // refuse to create a hint as a rescan is required already before any metadata edit
@@ -218,18 +214,6 @@ void CollectionScannerHintContainerImplementation::clear()
 
 // --------------------------------------------------------------------
 
-CollectionScanner::Private::Private()
-    : wantSignals         (false),
-      needTotalFiles      (false),
-      performFastScan     (true),
-      hints               (nullptr),
-      updatingHashHint    (false),
-      recordHistoryIds    (false),
-      deferredFileScanning(false),
-      observer            (nullptr)
-{
-}
-
 void CollectionScanner::Private::resetRemovedItemsTime()
 {
     removedItemsTime = QDateTime();
