@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_COLLECTION_SCANNER_P_H
-#define DIGIKAM_COLLECTION_SCANNER_P_H
+#pragma once
 
 #include "collectionscanner.h"
 
@@ -23,6 +22,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+
 #ifndef Q_CC_MSVC
 #   include <unistd.h>
 #endif
@@ -44,6 +44,7 @@
 
 #include "drawfiles.h"
 #include "digikam_debug.h"
+#include "digikam_globals.h"
 #include "coredb.h"
 #include "collectionmanager.h"
 #include "collectionlocation.h"
@@ -73,22 +74,31 @@ class Q_DECL_HIDDEN NewlyAppearedFile
 
 public:
 
-    NewlyAppearedFile();
+    NewlyAppearedFile() = default;
     NewlyAppearedFile(int albumId, const QString& fileName);
 
     bool operator==(const NewlyAppearedFile& other) const;
 
 public:
 
-    int     albumId;
+    int     albumId = 0;
     QString fileName;
 };
 
 // --------------------------------------------------------------------
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+inline size_t qHash(const NewlyAppearedFile& file)
+
+#else
+
 inline uint qHash(const NewlyAppearedFile& file)
+
+#endif
+
 {
-    return ::qHash(file.albumId) ^ ::qHash(file.fileName);
+    return (::qHash(file.albumId) ^ ::qHash(file.fileName));
 }
 
 // --------------------------------------------------------------------
@@ -130,7 +140,7 @@ class Q_DECL_HIDDEN CollectionScanner::Private
 
 public:
 
-    explicit Private();
+    Private() = default;
 
 public:
 
@@ -151,29 +161,27 @@ public:
     QSet<QString>                                 ignoreDirectory;
 
     QList<int>                                    scannedAlbums;
-    bool                                          wantSignals;
-    bool                                          needTotalFiles;
-    bool                                          performFastScan;
+    bool                                          wantSignals               = false;
+    bool                                          needTotalFiles            = false;
+    bool                                          performFastScan           = true;
 
     QDateTime                                     removedItemsTime;
 
-    CollectionScannerHintContainerImplementation* hints;
+    CollectionScannerHintContainerImplementation* hints                     = nullptr;
     QHash<int, int>                               establishedSourceAlbums;
-    bool                                          updatingHashHint;
+    bool                                          updatingHashHint          = false;
 
-    bool                                          recordHistoryIds;
+    bool                                          recordHistoryIds          = false;
     QSet<qlonglong>                               needResolveHistorySet;
     QSet<qlonglong>                               needTaggingHistorySet;
 
-    bool                                          deferredFileScanning;
+    bool                                          deferredFileScanning      = false;
     QSet<QString>                                 deferredAlbumPaths;
 
     QHash<QString, QDateTime>                     albumDateCache;
     QList<qlonglong>                              newIdsList;
 
-    CollectionScannerObserver*                    observer;
+    CollectionScannerObserver*                    observer                  = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_COLLECTION_SCANNER_P_H
