@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_LISTER_P_H
-#define DIGIKAM_ITEM_LISTER_P_H
+#pragma once
 
 #include "itemlister.h"
 
@@ -60,9 +59,19 @@ namespace Digikam
 {
 
 /**
- * Used by QSet
+ * Used by QSet.
  */
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+inline size_t qHash(const ItemListerRecord& key)
+
+#else
+
 inline uint qHash(const ItemListerRecord& key)
+
+#endif
+
 {
     return key.imageID;
 }
@@ -72,18 +81,12 @@ class Q_DECL_HIDDEN ItemLister::Private
 
 public:
 
-    explicit Private()
-      : recursive              (true),
-        listOnlyAvailableImages(true)
-    {
-    }
+    Private() = default;
 
 public:
 
-    bool recursive;
-    bool listOnlyAvailableImages;
+    bool recursive                  = true;
+    bool listOnlyAvailableImages    = true;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEM_LISTER_P_H
