@@ -9,14 +9,13 @@
  * SPDX-FileCopyrightText: 2007-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText:      2017 by Swati  Lodha   <swatilodha27 at gmail dot com>
- * SPDX-FileCopyrightText:      2018 by Mario Frank    <mario dot frank at uni minus potsdam dot de>
+ * SPDX-FileCopyrightText:      2018 by Mario  Frank   <mario dot frank at uni minus potsdam dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SIMILARITY_DB_SCHEMA_UPDATER_H
-#define DIGIKAM_SIMILARITY_DB_SCHEMA_UPDATER_H
+#pragma once
 
 namespace Digikam
 {
@@ -55,9 +54,7 @@ private:
     SimilarityDbSchemaUpdater& operator=(const SimilarityDbSchemaUpdater&) = delete;
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SIMILARITY_DB_SCHEMA_UPDATER_H
