@@ -38,14 +38,16 @@
 
 // KDE includes
 
+#include <kconfiggroup.h>
+#include <ksharedconfig.h>
 #include <klocalizedstring.h>
 
 // Local includes
 
 #include "digikam_debug.h"
 #include "applicationsettings.h"
-#include "coredburl.h"
 #include "dxmlguiwindow.h"
+#include "coredburl.h"
 
 namespace Digikam
 {
@@ -251,12 +253,8 @@ DeleteWidget::DeleteWidget(QWidget* const parent)
 {
     setObjectName(QLatin1String("DeleteDialogBase"));
 
-    resize(540, 370);
-    setMinimumSize(QSize(420, 320));
-
     const int spacing  = layoutSpacing();
 
-
     d->checkBoxStack   = new QStackedWidget(this);
     QLabel* const logo = new QLabel(this);
     logo->setPixmap(QIcon::fromTheme(QLatin1String("digikam")).pixmap(QSize(48,48)));
@@ -331,7 +329,7 @@ void DeleteWidget::setUrls(const QList<QUrl>& urls)
 {
     d->fileList->clear();
 
-    Q_FOREACH (const QUrl& url, urls)
+    for (const QUrl& url : std::as_const(urls))
     {
         new DeleteItem(d->fileList, url);
     }
@@ -475,7 +473,6 @@ DeleteDialog::DeleteDialog(QWidget* const parent)
                                                   QDialogButtonBox::Cancel |
                                                   QDialogButtonBox::Help,
                                                   this);
-    d->buttons->button(QDialogButtonBox::Apply)->setDefault(true);
 
     d->page                = new DeleteWidget(this);
     d->page->setMinimumSize(400, 300);
@@ -484,8 +481,6 @@ DeleteDialog::DeleteDialog(QWidget* const parent)
     vbx->addWidget(d->page);
     vbx->addWidget(d->buttons);
     setLayout(vbx);
-
-    setMinimumSize(410, 326);
     adjustSize();
 
     slotShouldDelete(shouldDelete());
@@ -501,11 +496,15 @@ DeleteDialog::DeleteDialog(QWidget* const parent)
 
     connect(d->buttons->button(QDialogButtonBox::Help), SIGNAL(clicked()),
             this, SLOT(slotHelp()));
-
 }
 
 DeleteDialog::~DeleteDialog()
 {
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group        = config->group(QLatin1String("Delete Dialog"));
+
+    DXmlGuiWindow::saveWindowSize(windowHandle(), group);
+
     delete d;
 }
 
@@ -588,6 +587,9 @@ void DeleteDialog::slotShouldDelete(bool shouldDelete)
                                                                       : i18n("&Move to Trash"));
     d->buttons->button(QDialogButtonBox::Apply)->setIcon(shouldDelete ? QIcon::fromTheme(QLatin1String("edit-delete"))
                                                                       : QIcon::fromTheme(QLatin1String("user-trash")));
+
+    d->buttons->button(QDialogButtonBox::Apply)->setDefault(!shouldDelete);
+    d->buttons->button(QDialogButtonBox::Cancel)->setDefault(shouldDelete);
 }
 
 void DeleteDialog::presetDeleteMode(DeleteDialogMode::DeleteMode mode)
@@ -682,6 +684,18 @@ void DeleteDialog::keyPressEvent(QKeyEvent* e)
     QDialog::keyPressEvent(e);
 }
 
+void DeleteDialog::showEvent(QShowEvent* e)
+{
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group        = config->group(QLatin1String("Delete Dialog"));
+
+    DXmlGuiWindow::setGoodDefaultWindowSize(windowHandle());
+    DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size());
+
+    QDialog::showEvent(e);
+}
+
 void DeleteDialog::slotHelp()
 {
     openOnlineDocumentation(QLatin1String("main_window"),
