@@ -6,7 +6,7 @@
  * Date        : 2005-05-25
  * Description : Raindrop threaded image filter.
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -43,19 +43,13 @@ class Q_DECL_HIDDEN RainDropFilter::Private
 
 public:
 
-    explicit Private()
-      : drop(80),
-        amount(150),
-        coeff(30),
-        selection(QRect(0, 0, 0, 0))
-    {
-    }
+    Private() = default;
 
-    int                   drop;
-    int                   amount;
-    int                   coeff;
+    int                   drop      = 80;
+    int                   amount    = 150;
+    int                   coeff     = 30;
 
-    QRect                 selection;
+    QRect                 selection = QRect(0, 0, 0, 0);
 
     RandomNumberGenerator generator;
 
@@ -64,7 +58,7 @@ public:
 
 RainDropFilter::RainDropFilter(QObject* const parent)
     : DImgThreadedFilter(parent),
-      d(new Private)
+      d                 (new Private)
 {
     initFilter();
 }
@@ -72,7 +66,7 @@ RainDropFilter::RainDropFilter(QObject* const parent)
 RainDropFilter::RainDropFilter(DImg* const orgImage, QObject* const parent, int drop,
                                int amount, int coeff, const QRect& selection)
     : DImgThreadedFilter(orgImage, parent, QLatin1String("RainDrop")),
-      d(new Private)
+      d                 (new Private)
 {
     d->drop      = drop;
     d->amount    = amount;
@@ -234,17 +228,23 @@ void RainDropFilter::rainDropsImage(DImg* const orgImage, DImg* const destImage,
             prm.stop         = vals[j+1];
 
             tasks.append(QtConcurrent::run(
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                                            &RainDropFilter::rainDropsImageMultithreaded, this,
+
 #else
+
                                            this, &RainDropFilter::rainDropsImageMultithreaded,
+
 #endif
+
                                            prm
                                           )
             );
         }
 
-        Q_FOREACH (QFuture<void> t, tasks)
+        for (QFuture<void> t : std::as_const(tasks))
         {
             t.waitForFinished();
         }
@@ -624,3 +624,5 @@ int RainDropFilter::pixelOffset(int Width, int X, int Y, int bytesDepth)
 }
 
 } // namespace Digikam
+
+#include "moc_raindropfilter.cpp"
