@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ICC_MANAGER_H
-#define DIGIKAM_ICC_MANAGER_H
+#pragma once
 
 // Local includes
 
@@ -141,9 +140,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ICC_MANAGER_H
