@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ANTI_VIGNETTING_SETTINGS_H
-#define DIGIKAM_ANTI_VIGNETTING_SETTINGS_H
+#pragma once
 
 // Local includes
 
@@ -60,9 +59,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ANTI_VIGNETTING_SETTINGS_H
