@@ -45,27 +45,20 @@ class Q_DECL_HIDDEN RedEyeCorrectionSettings::Private
 {
 public:
 
-    explicit Private()
-      : redtoavgratioInput(nullptr)
-    {
-    }
+    Private() = default;
 
-    static const QString configRedToAvgRatioAdjustmentEntry;
+    const QString configRedToAvgRatioAdjustmentEntry = QLatin1String("RedToAvgRatioAdjustment");
 
-    DDoubleNumInput* redtoavgratioInput;
+    DDoubleNumInput* redtoavgratioInput = nullptr;
 };
 
-const QString RedEyeCorrectionSettings::Private::configRedToAvgRatioAdjustmentEntry(QLatin1String("RedToAvgRatioAdjustment"));
-
 // --------------------------------------------------------
 
 RedEyeCorrectionSettings::RedEyeCorrectionSettings(QWidget* const parent)
     : QWidget(parent),
       d      (new Private)
 {
-    const int spacing       = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                   QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
-
+    const int spacing       = layoutSpacing();
     QGridLayout* const grid = new QGridLayout(parent);
 
     QLabel* const label2    = new QLabel(i18n("Red Level:"));
