@@ -40,6 +40,11 @@
 #   pragma GCC diagnostic ignored "-Wlogical-op"
 #endif
 
+#if defined(Q_CC_CLANG)
+#   pragma clang diagnostic push
+#   pragma clang diagnostic ignored "-Wunused-but-set-variable"
+#endif
+
 #include <Eigen/Eigen>
 #include <Eigen/LU>
 
@@ -48,6 +53,10 @@
 #   pragma GCC diagnostic pop
 #endif
 
+#if defined(Q_CC_CLANG)
+#   pragma clang diagnostic pop
+#endif
+
 // Local includes
 
 #include "digikam_debug.h"
