@@ -46,41 +46,30 @@ class Q_DECL_HIDDEN FreeRotationSettings::Private
 {
 public:
 
-    explicit Private()
-      : antialiasInput  (nullptr),
-        angleInput      (nullptr),
-        fineAngleInput  (nullptr),
-        autoCropCB      (nullptr),
-        backgroundColor (nullptr)
-    {
-    }
-
-    static const QString configAutoCropTypeEntry;
-    static const QString configAntiAliasingEntry;
-    static const QString configBackgroundColorEntry;
+    Private() = default;
 
 public:
 
-    QCheckBox*       antialiasInput;
+    const QString configAutoCropTypeEntry       = QLatin1String("Auto Crop Type");
+    const QString configAntiAliasingEntry       = QLatin1String("Anti Aliasing");
+    const QString configBackgroundColorEntry    = QLatin1String("Background Color");
 
-    DIntNumInput*    angleInput;
-    DDoubleNumInput* fineAngleInput;
-    DComboBox*       autoCropCB;
-    DColorSelector*  backgroundColor;
+    QCheckBox*       antialiasInput             = nullptr;
+
+    DIntNumInput*    angleInput                 = nullptr;
+    DDoubleNumInput* fineAngleInput             = nullptr;
+    DComboBox*       autoCropCB                 = nullptr;
+    DColorSelector*  backgroundColor            = nullptr;
 };
 
-const QString FreeRotationSettings::Private::configAutoCropTypeEntry(QLatin1String("Auto Crop Type"));
-const QString FreeRotationSettings::Private::configAntiAliasingEntry(QLatin1String("Anti Aliasing"));
-const QString FreeRotationSettings::Private::configBackgroundColorEntry(QLatin1String("Background Color"));
-
 // --------------------------------------------------------
 
 FreeRotationSettings::FreeRotationSettings(QWidget* const parent)
     : QWidget(parent),
       d      (new Private)
 {
-    const int spacing       = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                   QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing       = layoutSpacing();
+
 
     QGridLayout* const grid = new QGridLayout(this);
 
@@ -215,7 +204,6 @@ void FreeRotationSettings::readSettings(const KConfigGroup& group)
 
 void FreeRotationSettings::writeSettings(KConfigGroup& group)
 {
-    FreeRotationContainer prm = settings();
     group.writeEntry(d->configAutoCropTypeEntry,    d->autoCropCB->currentIndex());
     group.writeEntry(d->configAntiAliasingEntry,    d->antialiasInput->isChecked());
     group.writeEntry(d->configBackgroundColorEntry, d->backgroundColor->color());
