@@ -6,7 +6,7 @@
  * Date        : 2018-12-31
  * Description : configuration view for external plugin
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -75,22 +75,22 @@ public:
         setText(4, auth.join(QString::fromLatin1(", ")));
     };
 
-    ~DPluginCB() override
-    {
-    };
+    ~DPluginCB() override = default;
 
     bool contains(const QString& txt, Qt::CaseSensitivity cs) const
     {
-        return (text(0).contains(txt, cs) ||
+        return (
+                text(0).contains(txt, cs) ||
                 text(1).contains(txt, cs) ||
                 text(2).contains(txt, cs) ||
                 text(3).contains(txt, cs) ||
-                text(4).contains(txt, cs));
+                text(4).contains(txt, cs)
+               );
     };
 
 public:
 
-    DPlugin* m_plugin;
+    DPlugin* m_plugin = nullptr;
 
 private:
 
@@ -103,9 +103,7 @@ class Q_DECL_HIDDEN DPluginConfView::Private
 {
 public:
 
-    explicit Private()
-    {
-    }
+    Private() = default;
 
     QString           filter;
     QList<DPluginCB*> plugBoxes;
@@ -179,7 +177,7 @@ void DPluginConfView::apply()
         KSharedConfigPtr config = KSharedConfig::openConfig();
         KConfigGroup group      = config->group(loader->configGroupName());
 
-        Q_FOREACH (DPluginCB* const item, d->plugBoxes)
+        for (DPluginCB* const item : std::as_const(d->plugBoxes))
         {
             if (item->m_plugin->hasVisibilityProperty())
             {
@@ -196,7 +194,7 @@ void DPluginConfView::apply()
 
 void DPluginConfView::selectAll()
 {
-    Q_FOREACH (DPluginCB* const item, d->plugBoxes)
+    for (DPluginCB* const item : std::as_const(d->plugBoxes))
     {
         item->setCheckState(0, Qt::Checked);
     }
@@ -204,7 +202,7 @@ void DPluginConfView::selectAll()
 
 void DPluginConfView::clearAll()
 {
-    Q_FOREACH (DPluginCB* const item, d->plugBoxes)
+    for (DPluginCB* const item : std::as_const(d->plugBoxes))
     {
         item->setCheckState(0, Qt::Unchecked);
     }
@@ -219,7 +217,7 @@ int DPluginConfView::actived() const
 {
     int actived = 0;
 
-    Q_FOREACH (DPluginCB* const item, d->plugBoxes)
+    for (DPluginCB* const item : std::as_const(d->plugBoxes))
     {
         if (item->checkState(0) == Qt::Checked)
         {
@@ -234,7 +232,7 @@ int DPluginConfView::itemsVisible() const
 {
     int visible = 0;
 
-    Q_FOREACH (DPluginCB* const item, d->plugBoxes)
+    for (DPluginCB* const item : std::as_const(d->plugBoxes))
     {
         if (!item->isHidden())
         {
@@ -249,7 +247,7 @@ int DPluginConfView::itemsWithVisiblyProperty() const
 {
     int vp = 0;
 
-    Q_FOREACH (DPluginCB* const item, d->plugBoxes)
+    for (DPluginCB* const item : std::as_const(d->plugBoxes))
     {
         if (!item->isHidden() && item->m_plugin->hasVisibilityProperty())
         {
@@ -265,7 +263,7 @@ void DPluginConfView::setFilter(const QString& filter, Qt::CaseSensitivity cs)
     d->filter = filter;
     int found = 0;
 
-    Q_FOREACH (DPluginCB* const item, d->plugBoxes)
+    for (DPluginCB* const item : std::as_const(d->plugBoxes))
     {
         if (item->contains(filter, cs))
         {
@@ -287,3 +285,5 @@ QString DPluginConfView::filter() const
 }
 
 } // namespace Digikam
+
+#include "moc_dpluginconfview.cpp"
