@@ -7,15 +7,15 @@
  *
  * SPDX-FileCopyrightText: 2012-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * SPDX-FileCopyrightText:      2019 by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
- * SPDX-FileCopyrightText:      2020 by Nghia Duong <minhnghiaduong997 at gmail dot com>
+ * SPDX-FileCopyrightText: 2019      by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
+ * SPDX-FileCopyrightText: 2020      by Nghia Duong <minhnghiaduong997 at gmail dot com>
+ * SPDX-FileCopyrightText: 2024      by Michael Miller <michael underscore miller at msn dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_FACE_DB_P_H
-#define DIGIKAM_FACE_DB_P_H
+#pragma once
 
 #include "facedb.h"
 
@@ -26,23 +26,22 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "kd_tree.h"
+#include "kd_treebase.h"
 
 namespace Digikam
 {
 
 class Q_DECL_HIDDEN FaceDb::Private
 {
+public:
+
+    Private() = default;
 
 public:
-    explicit Private()
-        : db(nullptr)
-    {
-    }
 
-    FaceDbBackend* db;
+    FaceDbBackend* db                                     = nullptr;
+
+    FaceScanSettings::FaceRecognitionModel recognizeModel = FaceScanSettings::FaceRecognitionModel::OpenFace;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_FACE_DB_P_H
