@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_MIME_FILTER_H
-#define DIGIKAM_MIME_FILTER_H
+#pragma once
 
 // Qt includes
 
@@ -40,13 +39,13 @@ public:
         PNGFiles,
         TIFFiles,
         PGFFiles,
-        HEIFFiles,           // HEVC H265 compression based containers.
+        HEIFFiles,           ///< HEVC H265 compression based containers.
         AVIFFiles,
         DNGFiles,
-        RAWFiles,            // All Raw file formats such as nef, cr2, arw, pef, etc..
+        RAWFiles,            ///< All Raw file formats such as nef, cr2, arw, pef, etc..
         MoviesFiles,
         AudioFiles,
-        RasterGraphics       // PSD, XCF, etc...
+        RasterGraphics       ///< PSD, XCF, etc...
     };
 
 public:
@@ -59,5 +58,3 @@ public:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_MIME_FILTER_H
