@@ -14,11 +14,11 @@
  *
  * ============================================================ */
 
+#include "metaengine_p.h"
+
 // Local includes
 
-#include "metaengine_p.h"
 #include "digikam_debug.h"
-#include "digikam_config.h"
 
 #if defined(Q_CC_CLANG)
 #   pragma clang diagnostic push
@@ -34,21 +34,7 @@ bool MetaEngine::canWriteIptc(const QString& filePath)
 
     try
     {
-
-#if defined Q_OS_WIN && defined EXV_UNICODE_PATH
-
-        Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open((const wchar_t*)filePath.utf16());
-
-#elif defined Q_OS_WIN
-
-        Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open(QFile::encodeName(filePath).constData());
-
-#else
-
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open(filePath.toUtf8().constData());
-
-#endif
-
         Exiv2::AccessMode mode      = image->checkMode(Exiv2::mdIptc);
 
         return ((mode == Exiv2::amWrite) || (mode == Exiv2::amReadWrite));
@@ -113,9 +99,13 @@ QByteArray MetaEngine::getIptc(bool addIrbHeader) const
             }
 
 #if EXIV2_TEST_VERSION(0,27,99)
+
             QByteArray data((const char*)c2.data(), c2.size());
+
 #else
+
             QByteArray data((const char*)c2.pData_, c2.size_);
+
 #endif
 
             return data;
@@ -554,8 +544,10 @@ bool MetaEngine::setIptcTagsStringList(const char* iptcTagName, int maxSize,
 
             // Also remove new values to avoid duplicates. They will be added again below.
 
-            if ((key == QLatin1String(iptcTagName)) &&
-                (oldvals.contains(val) || newvals.contains(val)))
+            if (
+                (key == QLatin1String(iptcTagName)) &&
+                (oldvals.contains(val) || newvals.contains(val))
+               )
             {
                 it2 = iptcData.erase(it2);
             }
@@ -662,7 +654,8 @@ bool MetaEngine::setIptcKeywords(const QStringList& oldKeywords, const QStringLi
 
             // Also remove new keywords to avoid duplicates. They will be added again below.
 
-            if ((key == QLatin1String("Iptc.Application2.Keywords")) &&
+            if (
+                (key == QLatin1String("Iptc.Application2.Keywords")) &&
                 (oldKeywords.contains(val) || newKeywords.contains(val))
                )
             {
