@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_FOCUSPOINTS_WRITER_H
-#define DIGIKAM_FOCUSPOINTS_WRITER_H
+#pragma once
 
 // Qt includes
 
@@ -47,9 +46,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_FOCUSPOINTS_WRITER_H
