@@ -38,6 +38,9 @@
 #include <QLocale>
 #include <QScopedPointer>
 #include <QStackedWidget>
+#include <QApplication>
+#include <QClipboard>
+#include <QMimeData>
 
 // KDE includes
 
@@ -53,10 +56,7 @@
 #include "itemgpsmodelhelper.h"
 #include "dexpanderbox.h"
 #include "digikam_config.h"
-
-#ifdef HAVE_QWEBENGINE
-#   include "webbrowserdlg.h"
-#endif
+#include "webbrowserdlg.h"
 
 namespace Digikam
 {
@@ -66,49 +66,31 @@ class Q_DECL_HIDDEN ItemPropertiesGPSTab::Private
 
 public:
 
-    explicit Private()
-      : altLabel                    (nullptr),
-        latLabel                    (nullptr),
-        lonLabel                    (nullptr),
-        dateLabel                   (nullptr),
-        mapView                     (nullptr),
-        detailsBtn                  (nullptr),
-        detailsCombo                (nullptr),
-        altitude                    (nullptr),
-        latitude                    (nullptr),
-        longitude                   (nullptr),
-        date                        (nullptr),
-        map                         (nullptr),
-        itemMarkerTiler             (nullptr),
-        itemModel                   (nullptr),
-        gpsModelHelper              (nullptr),
-        gpsItemInfoSorter           (nullptr),
-        boundariesShouldBeAdjusted  (false)
-    {
-    }
+    Private() = default;
 
-    QLabel*                    altLabel;
-    QLabel*                    latLabel;
-    QLabel*                    lonLabel;
-    QLabel*                    dateLabel;
+    QLabel*                    altLabel                     = nullptr;
+    QLabel*                    latLabel                     = nullptr;
+    QLabel*                    lonLabel                     = nullptr;
+    QLabel*                    dateLabel                    = nullptr;
 
-    QStackedWidget*            mapView;
-    QToolButton*               detailsBtn;
-    QComboBox*                 detailsCombo;
+    QStackedWidget*            mapView                      = nullptr;
+    QToolButton*               detailsBtn                   = nullptr;
+    QToolButton*               gpsCopyBtn                   = nullptr;
+    QComboBox*                 detailsCombo                 = nullptr;
 
-    DAdjustableLabel*          altitude;
-    DAdjustableLabel*          latitude;
-    DAdjustableLabel*          longitude;
-    DAdjustableLabel*          date;
+    DAdjustableLabel*          altitude                     = nullptr;
+    DAdjustableLabel*          latitude                     = nullptr;
+    DAdjustableLabel*          longitude                    = nullptr;
+    DAdjustableLabel*          date                         = nullptr;
 
-    MapWidget*                 map;
-    ItemMarkerTiler*           itemMarkerTiler;
+    MapWidget*                 map                          = nullptr;
+    ItemMarkerTiler*           itemMarkerTiler              = nullptr;
     GPSItemInfo::List          gpsInfoList;
 
-    QStandardItemModel*        itemModel;
-    ItemGPSModelHelper*        gpsModelHelper;
-    GPSItemInfoSorter*         gpsItemInfoSorter;
-    bool                       boundariesShouldBeAdjusted;
+    QStandardItemModel*        itemModel                    = nullptr;
+    ItemGPSModelHelper*        gpsModelHelper               = nullptr;
+    GPSItemInfoSorter*         gpsItemInfoSorter            = nullptr;
+    bool                       boundariesShouldBeAdjusted   = false;
 };
 
 ItemPropertiesGPSTab::ItemPropertiesGPSTab(QWidget* const parent)
@@ -171,6 +153,10 @@ ItemPropertiesGPSTab::ItemPropertiesGPSTab(QWidget* const parent)
     QWidget* const box            = new DHBox(this);
     QHBoxLayout* const hBoxLayout = reinterpret_cast<QHBoxLayout*>(box->layout());
 
+    d->gpsCopyBtn                 = new QToolButton(box);
+    d->gpsCopyBtn->setIcon(QIcon::fromTheme(QLatin1String("edit-copy")));
+    d->gpsCopyBtn->setToolTip(i18n("Copy GPS coordinates to clipboard"));
+
     if (hBoxLayout)
     {
         hBoxLayout->addStretch();
@@ -208,6 +194,9 @@ ItemPropertiesGPSTab::ItemPropertiesGPSTab(QWidget* const parent)
 
     connect(d->detailsBtn, SIGNAL(clicked()),
             this, SLOT(slotGPSDetails()));
+
+    connect(d->gpsCopyBtn, SIGNAL(clicked()),
+            this, SLOT(slotCopyGPSDetails()));
 }
 
 ItemPropertiesGPSTab::~ItemPropertiesGPSTab()
@@ -312,17 +301,25 @@ void ItemPropertiesGPSTab::slotGPSDetails()
 
     qCDebug(DIGIKAM_GENERAL_LOG) << url;
 
-#ifdef HAVE_QWEBENGINE
-
     WebBrowserDlg* const browser = new WebBrowserDlg(QUrl(url), this);
     browser->show();
+}
 
-#else
+void ItemPropertiesGPSTab::slotCopyGPSDetails()
+{
+    if (d->gpsInfoList.isEmpty())
+    {
+        return;
+    }
 
-    QDesktopServices::openUrl(QUrl(url));
-
-#endif
+    const GPSItemInfo info = d->gpsInfoList.first();
+    QString copyGPSText    = QString::fromLatin1("%1, %2")
+                                 .arg(info.coordinates.lat(), 0, 'g', 12)
+                                 .arg(info.coordinates.lon(), 0, 'g', 12);
 
+    QMimeData* const mimeData = new QMimeData();
+    mimeData->setText(copyGPSText);
+    QApplication::clipboard()->setMimeData(mimeData, QClipboard::Clipboard);
 }
 
 void ItemPropertiesGPSTab::setCurrentURL(const QUrl& url)
@@ -414,10 +411,15 @@ void ItemPropertiesGPSTab::setGPSInfoList(const GPSItemInfo::List& list)
             d->altitude->setAdjustedText(QString::fromLatin1("%1 m").arg(QLocale().toString(coordinates.alt(), 'g', 7)));
         }
 
+        d->gpsCopyBtn->setEnabled(true);
         d->latitude->setAdjustedText(QLocale().toString(coordinates.lat(), 'g', 7));
         d->longitude->setAdjustedText(QLocale().toString(coordinates.lon(), 'g', 7));
         d->date->setAdjustedText(QLocale().toString(info.dateTime, QLocale::ShortFormat));
     }
+    else
+    {
+        d->gpsCopyBtn->setEnabled(false);
+    }
 
     for (int i = 0 ; i < d->gpsInfoList.count() ; ++i)
     {
