@@ -6,14 +6,13 @@
  * Date        : 2004-11-17
  * Description : item properties side bar (without support of digiKam database).
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_PROPERTIES_SIDEBAR_H
-#define DIGIKAM_ITEM_PROPERTIES_SIDEBAR_H
+#pragma once
 
 // Qt includes
 
@@ -39,11 +38,11 @@ class ItemSelectionPropertiesTab;
 class ItemPropertiesMetadataTab;
 class ItemPropertiesColorsTab;
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
 class ItemPropertiesGPSTab;
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
 class DIGIKAM_EXPORT ItemPropertiesSideBar : public Sidebar
 {
@@ -54,7 +53,7 @@ public:
                                    SidebarSplitter* const splitter,
                                    Qt::Edge side = Qt::LeftEdge,
                                    bool mimimizedDefault = false);
-    ~ItemPropertiesSideBar() override;
+    ~ItemPropertiesSideBar() override = default;
 
     virtual void itemChanged(const QUrl& url, const QRect& rect = QRect(), DImg* const img = nullptr);
 
@@ -89,33 +88,31 @@ protected:
 
 protected:
 
-    bool                        m_dirtyPropertiesTab;
-    bool                        m_dirtyMetadataTab;
-    bool                        m_dirtyColorTab;
-    bool                        m_dirtyGpsTab;
-    bool                        m_dirtyHistoryTab;
+    bool                        m_dirtyPropertiesTab        = false;
+    bool                        m_dirtyMetadataTab          = false;
+    bool                        m_dirtyColorTab             = false;
+    bool                        m_dirtyGpsTab               = false;
+    bool                        m_dirtyHistoryTab           = false;
 
     QRect                       m_currentRect;
 
     QUrl                        m_currentURL;
 
-    DImg*                       m_image;
+    DImg*                       m_image                     = nullptr;
 
-    QStackedWidget*             m_propertiesStackedView;
+    QStackedWidget*             m_propertiesStackedView     = nullptr;
 
-    ItemPropertiesTab*          m_propertiesTab;
-    ItemSelectionPropertiesTab* m_selectionPropertiesTab;
-    ItemPropertiesMetadataTab*  m_metadataTab;
-    ItemPropertiesColorsTab*    m_colorTab;
+    ItemPropertiesTab*          m_propertiesTab             = nullptr;
+    ItemSelectionPropertiesTab* m_selectionPropertiesTab    = nullptr;
+    ItemPropertiesMetadataTab*  m_metadataTab               = nullptr;
+    ItemPropertiesColorsTab*    m_colorTab                  = nullptr;
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
-    ItemPropertiesGPSTab*       m_gpsTab;
+    ItemPropertiesGPSTab*       m_gpsTab                    = nullptr;
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEM_PROPERTIES_SIDEBAR_H
