@@ -7,7 +7,7 @@
  * Description : application settings interface
  *
  * SPDX-FileCopyrightText: 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2003-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2007      by Arnd Baecker <arnd dot baecker at web dot de>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * SPDX-FileCopyrightText: 2014      by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail dot com>
@@ -132,6 +132,16 @@ bool ApplicationSettings::getDrawFramesToGrouped() const
     return d->drawFramesToGrouped;
 }
 
+void ApplicationSettings::setSelectFirstAlbumItem(bool val)
+{
+    d->selectFirstAlbumItem = val;
+}
+
+bool ApplicationSettings::getSelectFirstAlbumItem() const
+{
+    return d->selectFirstAlbumItem;
+}
+
 void ApplicationSettings::setExpandNewCurrentItem(bool val)
 {
     d->expandNewCurrentItem = val;
@@ -197,24 +207,54 @@ VersionManagerSettings ApplicationSettings::getVersionManagerSettings() const
     return d->versionSettings;
 }
 
-double ApplicationSettings::getFaceDetectionAccuracy() const
+int ApplicationSettings::getFaceDetectionAccuracy() const
 {
     return d->faceDetectionAccuracy;
 }
 
-void ApplicationSettings::setFaceDetectionAccuracy(double value)
+void ApplicationSettings::setFaceDetectionAccuracy(int value)
 {
     d->faceDetectionAccuracy = value;
 }
 
-bool ApplicationSettings::getFaceDetectionYoloV3() const
+FaceScanSettings::FaceDetectionModel ApplicationSettings::getFaceDetectionModel() const
 {
-    return d->faceDetectionYoloV3;
+    return d->faceDetectionModel;
 }
 
-void ApplicationSettings::setFaceDetectionYoloV3(bool yolo)
+void ApplicationSettings::setFaceDetectionModel(FaceScanSettings::FaceDetectionModel model)
 {
-    d->faceDetectionYoloV3 = yolo;
+    d->faceDetectionModel = model;
+}
+
+FaceScanSettings::FaceDetectionSize ApplicationSettings::getFaceDetectionSize() const
+{
+    return d->faceDetectionSize;
+}
+
+void ApplicationSettings::setFaceDetectionSize(FaceScanSettings::FaceDetectionSize size)
+{
+    d->faceDetectionSize = size;
+}
+
+int ApplicationSettings::getFaceRecognitionAccuracy() const
+{
+    return d->faceRecognitionAccuracy;
+}
+
+void ApplicationSettings::setFaceRecognitionAccuracy(int value)
+{
+    d->faceRecognitionAccuracy = value;
+}
+
+FaceScanSettings::FaceRecognitionModel ApplicationSettings::getFaceRecognitionModel() const
+{
+    return d->faceRecognitionModel;
+}
+
+void ApplicationSettings::setFaceRecognitionModel(FaceScanSettings::FaceRecognitionModel model)
+{
+    d->faceRecognitionModel = model;
 }
 
 void ApplicationSettings::setApplicationStyle(const QString& style)
@@ -354,7 +394,7 @@ int  ApplicationSettings::getDuplicatesSearchRestrictions() const
     return d->duplicatesSearchLastRestrictions;
 }
 
-void ApplicationSettings::setGroupingOperateOnAll(ApplicationSettings::OperationType type,
+void ApplicationSettings::setGroupingOperateOnAll(OperationType type,
                                                   ApplicationSettings::ApplyToEntireGroup applyAll)
 {
     if (!d->groupingOperateOnAll.contains(type))
@@ -363,18 +403,19 @@ void ApplicationSettings::setGroupingOperateOnAll(ApplicationSettings::Operation
     }
 
     d->groupingOperateOnAll[type] = applyAll;
+
     return;
 }
 
 ApplicationSettings::ApplyToEntireGroup ApplicationSettings::getGroupingOperateOnAll(
-        ApplicationSettings::OperationType type) const
+        OperationType type) const
 {
     if (!d->groupingOperateOnAll.contains(type))
     {
         throw std::invalid_argument("ApplicationSettings::getGroupingOperateOnAll: Invalid operation type.");
     }
 
-    if (type == ApplicationSettings::Unspecified)
+    if (type == UnspecifiedOps)
     {
         return ApplicationSettings::No;
     }
@@ -382,14 +423,14 @@ ApplicationSettings::ApplyToEntireGroup ApplicationSettings::getGroupingOperateO
     return d->groupingOperateOnAll[type];
 }
 
-bool ApplicationSettings::askGroupingOperateOnAll(ApplicationSettings::OperationType type)
+bool ApplicationSettings::askGroupingOperateOnAll(OperationType type)
 {
     if (!d->groupingOperateOnAll.contains(type))
     {
         throw std::invalid_argument("ApplicationSettings::askGroupingOperateOnAll: Invalid operation type.");
     }
 
-    if (type == ApplicationSettings::Unspecified)
+    if (type == UnspecifiedOps)
     {
         return false;
     }
@@ -423,63 +464,97 @@ bool ApplicationSettings::askGroupingOperateOnAll(ApplicationSettings::Operation
     return true;
 }
 
-QString ApplicationSettings::operationTypeTitle(ApplicationSettings::OperationType type)
+QString ApplicationSettings::operationTypeTitle(OperationType type)
 {
     switch (type)
     {
-        case ApplicationSettings::Metadata:
+        case MetadataOps:
+        {
             return i18n("Metadata");
+        }
 
-        case ApplicationSettings::LightTable:
+        case LightTableOps:
+        {
             return i18n("Light Table");
+        }
 
-        case ApplicationSettings::BQM:
+        case BQMOps:
+        {
             return i18n("Batch Queue Manager");
+        }
 
-        case ApplicationSettings::Slideshow:
+        case SlideshowOps:
+        {
             return i18n("Slideshow");
+        }
 
-        case ApplicationSettings::Rename:
+        case RenameOps:
+        {
             return i18n("Renaming");
+        }
 
-        case ApplicationSettings::ImportExport:
+        case ImportExportOps:
+        {
             return i18n("Import/Export tools");
+        }
 
-        case ApplicationSettings::Tools:
+        case ToolsOps:
+        {
             return i18n("Tools (editor, panorama, stack blending, calendar, "
                         "external program)");
+        }
+
         default:
+        {
             throw std::invalid_argument("ApplicationSettings::operationTypeTitle: Invalid operation type.");
+        }
     }
 }
 
-QString ApplicationSettings::operationTypeExplanation(ApplicationSettings::OperationType type)
+QString ApplicationSettings::operationTypeExplanation(OperationType type)
 {
     switch (type)
     {
-        case ApplicationSettings::Metadata:
+        case MetadataOps:
+        {
             return i18n("Operations related to metadata, labels, ratings, tags, geolocation and rotation");
+        }
 
-        case ApplicationSettings::LightTable:
+        case LightTableOps:
+        {
             return i18n("Adding items to the Light Table");
+        }
 
-        case ApplicationSettings::BQM:
+        case BQMOps:
+        {
             return i18n("Adding items to the Batch Queue Manager");
+        }
 
-        case ApplicationSettings::Slideshow:
+        case SlideshowOps:
+        {
             return i18n("Opening items in the Slideshow");
+        }
 
-        case ApplicationSettings::Rename:
+        case RenameOps:
+        {
             return i18n("Renaming items");
+        }
 
-        case ApplicationSettings::ImportExport:
+        case ImportExportOps:
+        {
             return i18n("Passing items to import/export tools");
+        }
 
-        case ApplicationSettings::Tools:
+        case ToolsOps:
+        {
             return i18n("Several tools including the editor, panorama, stack blending, "
                         "calendar, html gallery and opening with external programs");
+        }
+
         default:
+        {
             return QString();
+        }
     }
 }
 
@@ -501,7 +576,7 @@ QFont ApplicationSettings::getApplicationFont() const
 bool ApplicationSettings::getHelpBoxNotificationSeen()
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup group      = config->group("Notification Messages");
+    KConfigGroup group      = config->group(QLatin1String("Notification Messages"));
     bool value              = group.readEntry("HelpBoxNotifSeen", false);
 
     return value;
@@ -510,7 +585,7 @@ bool ApplicationSettings::getHelpBoxNotificationSeen()
 void ApplicationSettings::setHelpBoxNotificationSeen(bool val)
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup group      = config->group("Notification Messages");
+    KConfigGroup group      = config->group(QLatin1String("Notification Messages"));
 
     group.writeEntry("HelpBoxNotifSeen", val);
     config->sync();
