@@ -48,7 +48,7 @@ public:
 
 TagMngrTreeView::TagMngrTreeView(TagsManager* const parent, TagModel* const model)
     : TagFolderView(parent, model),
-      d            (new Private())
+      d            (new Private)
 {
     d->tagMngr = parent;
     setAlbumFilterModel(new TagsManagerFilterModel(this), albumFilterModel());
@@ -68,7 +68,7 @@ void TagMngrTreeView::contextMenuEvent(QContextMenuEvent* event)
     std::sort(selectedItems.begin(), selectedItems.end());
     QList<TAlbum*> items;
 
-    Q_FOREACH (const QModelIndex& mIndex, selectedItems)
+    for (const QModelIndex& mIndex : std::as_const(selectedItems))
     {
         TAlbum* const temp = static_cast<TAlbum*>(albumForIndex(mIndex));
         items.append(temp);
@@ -89,6 +89,7 @@ void TagMngrTreeView::contextMenuEvent(QContextMenuEvent* event)
     setContexMenuItems(cmhelper, items);
 
     QAction* const choice = cmhelper.exec(QCursor::pos());
+
     Q_UNUSED(choice);
     Q_UNUSED(event);
 }
@@ -97,6 +98,7 @@ void TagMngrTreeView::setAlbumFilterModel(TagsManagerFilterModel* const filtered
                                           CheckableAlbumFilterModel* const filterModel)
 {
     Q_UNUSED(filterModel);
+
     m_tfilteredModel = filteredModel;
     albumFilterModel()->setSourceFilterModel(m_tfilteredModel);
 }
