@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DHUE_SATURATION_SELECT_H
-#define DIGIKAM_DHUE_SATURATION_SELECT_H
+#pragma once
 
 // Qt includes
 
@@ -42,7 +41,7 @@ public:
      * has a value range of [0..100] in both directions.
      */
     explicit DPointSelect(QWidget* const parent);
-    ~DPointSelect() override;
+    ~DPointSelect()                         override;
 
     /**
      * Sets the current values in horizontal and
@@ -111,7 +110,9 @@ protected:
      *
      * Draw within contentsRect() only.
      */
-    virtual void drawContents(QPainter*) {};
+    virtual void drawContents(QPainter*)
+    {
+    };
 
     /**
      * Override this function to draw the marker which
@@ -119,10 +120,10 @@ protected:
      */
     virtual void drawMarker(QPainter* p, int xp, int yp);
 
-    void paintEvent(QPaintEvent* e) override;
-    void mousePressEvent(QMouseEvent* e) override;
-    void mouseMoveEvent(QMouseEvent* e) override;
-    void wheelEvent(QWheelEvent*) override;
+    void paintEvent(QPaintEvent* e)         override;
+    void mousePressEvent(QMouseEvent* e)    override;
+    void mouseMoveEvent(QMouseEvent* e)     override;
+    void wheelEvent(QWheelEvent*)           override;
 
     /**
      * Converts a pixel position to its corresponding values.
@@ -140,7 +141,7 @@ private:
 
     class Private;
     friend class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 // --------------------------------------------------------------------------------
@@ -159,7 +160,7 @@ public:
     /**
      * Destructor.
      */
-    ~DHueSaturationSelector() override;
+    ~DHueSaturationSelector()                   override;
 
     /**
      * Sets the chooser mode. The allowed modes are defined
@@ -231,14 +232,14 @@ protected:
      * which is used for buffering.
      */
     virtual void drawPalette(QPixmap* pixmap);
-    void resizeEvent(QResizeEvent*) override;
+    void resizeEvent(QResizeEvent*)             override;
 
     /**
      * Reimplemented from DPointSelect. This drawing is
      * buffered in a pixmap here. As real drawing
      * routine, drawPalette() is used.
      */
-    void drawContents(QPainter* painter) override;
+    void drawContents(QPainter* painter)        override;
 
 private:
 
@@ -246,9 +247,7 @@ private:
 
     class Private;
     friend class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DHUE_SATURATION_SELECT_H
