@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TIMEZONE_COMBOBOX_H
-#define DIGIKAM_TIMEZONE_COMBOBOX_H
+#pragma once
 
 // Qt includes
 
@@ -34,7 +33,7 @@ class DIGIKAM_EXPORT TimeZoneComboBox : public QComboBox
 public:
 
     explicit TimeZoneComboBox(QWidget* const parent);
-    ~TimeZoneComboBox()            override;
+    ~TimeZoneComboBox()            override = default;
 
     void setToUTC();
     void setTimeZone(const QString& timeStr);
@@ -44,5 +43,3 @@ public:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TIMEZONE_COMBOBOX_H
