@@ -39,7 +39,6 @@ void DCategorizedView::setGridSize(const QSize& size)
 
 void DCategorizedView::setModel(QAbstractItemModel* model)
 {
-    d->lastSelection           = QItemSelection();
     d->forcedSelectionPosition = 0;
     d->hovered                 = QModelIndex();
     d->mouseButtonPressed      = false;
@@ -50,6 +49,8 @@ void DCategorizedView::setModel(QAbstractItemModel* model)
     d->categoriesPosition.clear();
     d->categories.clear();
     d->intersectedIndexes.clear();
+    d->lastSelection.clear();
+    d->lastCategorySelection.clear();
 
     if (d->proxyModel)
     {
@@ -124,7 +125,7 @@ QModelIndex DCategorizedView::categoryAt(const QPoint& point) const
     int lastY = 0;
     QString lastCategory;
 
-    Q_FOREACH (const QString& category, d->categories)
+    for (const QString& category : std::as_const(d->categories))
     {
         y = d->categoryVisualRect(category).top();
 
@@ -174,7 +175,6 @@ DCategoryDrawer* DCategorizedView::categoryDrawer() const
 
 void DCategorizedView::setCategoryDrawer(DCategoryDrawer* categoryDrawer)
 {
-    d->lastSelection           = QItemSelection();
     d->forcedSelectionPosition = 0;
     d->hovered                 = QModelIndex();
     d->mouseButtonPressed      = false;
@@ -185,6 +185,8 @@ void DCategorizedView::setCategoryDrawer(DCategoryDrawer* categoryDrawer)
     d->categoriesPosition.clear();
     d->categories.clear();
     d->intersectedIndexes.clear();
+    d->lastSelection.clear();
+    d->lastCategorySelection.clear();
     d->categoryDrawer          = categoryDrawer;
 
     if (categoryDrawer)
@@ -241,7 +243,6 @@ void DCategorizedView::reset()
 {
     QListView::reset();
 
-    d->lastSelection           = QItemSelection();
     d->forcedSelectionPosition = 0;
     d->hovered                 = QModelIndex();
     d->biggestItemSize         = QSize(0, 0);
@@ -253,6 +254,8 @@ void DCategorizedView::reset()
     d->categoriesPosition.clear();
     d->categories.clear();
     d->intersectedIndexes.clear();
+    d->lastSelection.clear();
+    d->lastCategorySelection.clear();
 }
 
 void DCategorizedView::paintEvent(QPaintEvent* event)
@@ -299,7 +302,7 @@ void DCategorizedView::paintEvent(QPaintEvent* event)
         alternate = (dirtyIndexes[0].row() % 2);
     }
 
-    Q_FOREACH (const QModelIndex& index, dirtyIndexes)
+    for (const QModelIndex& index : std::as_const(dirtyIndexes))
     {
         if      (alternatingRows && alternate)
         {
@@ -373,7 +376,7 @@ void DCategorizedView::paintEvent(QPaintEvent* event)
     QStyleOptionViewItem otherOption;
     bool                 intersectedInThePast = false;
 
-    Q_FOREACH (const QString& category, d->categories)
+    for (const QString& category : std::as_const(d->categories))
     {
         otherOption        = option;
         otherOption.rect   = d->categoryVisualRect(category);
@@ -731,6 +734,7 @@ void DCategorizedView::setSelection(const QRect& rect, QItemSelectionModel::Sele
     }
 
     selectionModel()->select(selection, command);
+    d->lastCategorySelection.clear();
 }
 
 void DCategorizedView::mouseMoveEvent(QMouseEvent* event)
@@ -774,7 +778,7 @@ void DCategorizedView::mouseMoveEvent(QMouseEvent* event)
 
     // Redraw categories
 
-    Q_FOREACH (const QString& category, d->categories)
+    for (const QString& category : std::as_const(d->categories))
     {
         if      (d->categoryVisualRect(category).intersects(QRect(event->pos(), event->pos())))
         {
@@ -870,7 +874,7 @@ void DCategorizedView::mouseReleaseEvent(QMouseEvent* event)
         (initPressPos == d->initialPressPosition)
        )
     {
-        Q_FOREACH (const QString& category, d->categories)
+        for (const QString& category : std::as_const(d->categories))
         {
             if (
                 d->categoryVisualRect(category).contains(event->pos()) &&
@@ -880,14 +884,23 @@ void DCategorizedView::mouseReleaseEvent(QMouseEvent* event)
                 QItemSelection selection      = selectionModel()->selection();
                 const QVector<int>& indexList = d->categoriesIndexes[category];
 
-                Q_FOREACH (int row, indexList)
+                for (int row : std::as_const(indexList))
                 {
                     QModelIndex selectIndex = d->proxyModel->index(row, 0);
 
                     selection << QItemSelectionRange(selectIndex);
                 }
 
-                selectionModel()->select(selection, QItemSelectionModel::SelectCurrent);
+                if (d->lastCategorySelection == selection)
+                {
+                    selectionModel()->select(selection, QItemSelectionModel::Deselect);
+                    d->lastCategorySelection.clear();
+                }
+                else
+                {
+                    selectionModel()->select(selection, QItemSelectionModel::SelectCurrent);
+                    d->lastCategorySelection = selection;
+                }
 
                 break;
             }
@@ -1115,7 +1128,7 @@ QModelIndex DCategorizedView::moveCursor(CursorAction cursorAction,
     QString afterCategory = d->categories.first();
     bool hasToBreak       = false;
 
-    Q_FOREACH (const QString& category, d->categories)
+    for (const QString& category : std::as_const(d->categories))
     {
         // cppcheck-suppress knownConditionTrueFalse
         if (hasToBreak)
