@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EXIF_TOOL_LIST_VIEW_ITEM_H
-#define DIGIKAM_EXIF_TOOL_LIST_VIEW_ITEM_H
+#pragma once
 
 // Qt includes
 
@@ -51,10 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
-
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_EXIF_TOOL_LIST_VIEW_ITEM_H
