@@ -41,12 +41,12 @@ public:
     enum Style
     {
         STYLE_NOQUIRK,
-        STYLE_MACINTOSH,
         STYLE_PLASTIQUE,
         STYLE_WINDOWS,
         STYLE_BREEZE,
         STYLE_FUSION,
         STYLE_OXYGEN,
+        STYLE_MACOS,
         STYLE_GTK2
     };
 
@@ -224,9 +224,9 @@ void DAbstractSliderSpinBox::paint(QPainter& painter)
 
     if (
         (d->style == DAbstractSliderSpinBoxPrivate::STYLE_GTK2)    ||
+        (d->style == DAbstractSliderSpinBoxPrivate::STYLE_MACOS)   ||
         (d->style == DAbstractSliderSpinBoxPrivate::STYLE_OXYGEN)  ||
-        (d->style == DAbstractSliderSpinBoxPrivate::STYLE_WINDOWS) ||
-        (d->style == DAbstractSliderSpinBoxPrivate::STYLE_MACINTOSH)
+        (d->style == DAbstractSliderSpinBoxPrivate::STYLE_WINDOWS)
        )
     {
         progressOpts.state |= QStyle::State_Horizontal;
@@ -720,7 +720,6 @@ QSize DAbstractSliderSpinBox::sizeHint() const
             break;
         }
 
-        case DAbstractSliderSpinBoxPrivate::STYLE_MACINTOSH:
         case DAbstractSliderSpinBoxPrivate::STYLE_WINDOWS:
         case DAbstractSliderSpinBoxPrivate::STYLE_FUSION:
         case DAbstractSliderSpinBoxPrivate::STYLE_OXYGEN:
@@ -730,6 +729,12 @@ QSize DAbstractSliderSpinBox::sizeHint() const
             break;
         }
 
+        case DAbstractSliderSpinBoxPrivate::STYLE_MACOS:
+        {
+            hint += QSize(8, 16);
+            break;
+        }
+
         case DAbstractSliderSpinBoxPrivate::STYLE_NOQUIRK:
         {
             // almost all "modern" styles have a margin around controls
@@ -1019,11 +1024,7 @@ void DAbstractSliderSpinBox::changeEvent(QEvent* e)
 
     if (e->type() == QEvent::StyleChange)
     {
-        if      (style()->objectName() == QLatin1String("macintosh"))
-        {
-            d->style = DAbstractSliderSpinBoxPrivate::STYLE_MACINTOSH;
-        }
-        else if (style()->objectName() == QLatin1String("plastique"))
+        if      (style()->objectName() == QLatin1String("plastique"))
         {
             d->style = DAbstractSliderSpinBoxPrivate::STYLE_PLASTIQUE;
         }
@@ -1043,6 +1044,10 @@ void DAbstractSliderSpinBox::changeEvent(QEvent* e)
         {
             d->style = DAbstractSliderSpinBoxPrivate::STYLE_OXYGEN;
         }
+        else if (style()->objectName() == QLatin1String("macos"))
+        {
+            d->style = DAbstractSliderSpinBoxPrivate::STYLE_MACOS;
+        }
         else if (style()->objectName() == QLatin1String("gtk2"))
         {
             d->style = DAbstractSliderSpinBoxPrivate::STYLE_GTK2;
