@@ -6,18 +6,9 @@
  * Date        : 2007-02-06
  * Description : setup RAW decoding settings.
  *
- * Copyright (C) 2007-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -40,14 +31,10 @@ class Q_DECL_HIDDEN ShowfotoSetupRaw::Private
 {
 public:
 
-    explicit Private()
-      : tab(nullptr),
-        raw(nullptr)
-    {
-    }
+    Private() = default;
 
-    QTabWidget* tab;
-    SetupRaw*   raw;
+    QTabWidget* tab = nullptr;
+    SetupRaw*   raw = nullptr;
 };
 
 ShowfotoSetupRaw::ShowfotoSetupRaw(QWidget* const parent)
@@ -68,6 +55,16 @@ ShowfotoSetupRaw::~ShowfotoSetupRaw()
     delete d;
 }
 
+void ShowfotoSetupRaw::setActiveTab(RAWTab tab)
+{
+    d->tab->setCurrentIndex(tab);
+}
+
+ShowfotoSetupRaw::RAWTab ShowfotoSetupRaw::activeTab() const
+{
+    return (RAWTab)d->tab->currentIndex();
+}
+
 void ShowfotoSetupRaw::applySettings()
 {
     d->raw->applySettings();
@@ -79,3 +76,5 @@ void ShowfotoSetupRaw::readSettings()
 }
 
 } // namespace ShowFoto
+
+#include "moc_showfotosetupraw.cpp"
