@@ -65,64 +65,40 @@ class Q_DECL_HIDDEN ShowfotoStackViewFavoriteItemDlg::Private
 {
 public:
 
-    explicit Private()
-      : create         (false),
-        hierarchyLabel (nullptr),
-        icon           (QLatin1String("folder-favorites")),
-        iconButton     (nullptr),
-        resetIconButton(nullptr),
-        dateLowButton  (nullptr),
-        dateAvgButton  (nullptr),
-        dateHighButton (nullptr),
-        buttons        (nullptr),
-        nameEdit       (nullptr),
-        descEdit       (nullptr),
-        favoriteTypeBox(nullptr),
-        dateEdit       (nullptr),
-        urlsEdit       (nullptr),
-        descLabel      (nullptr),
-        nbImagesLabel  (nullptr),
-        dateLabel      (nullptr),
-        iconTextLabel  (nullptr),
-        urlsLabel      (nullptr),
-        helpLabel      (nullptr),
-        list           (nullptr),
-        pitem          (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool                           create;
+    bool                           create           = false;
 
-    DAdjustableLabel*              hierarchyLabel;
+    DAdjustableLabel*              hierarchyLabel   = nullptr;
 
-    QString                        icon;
+    QString                        icon             = QLatin1String("folder-favorites");
     QString                        originalName;
 
-    QPushButton*                   iconButton;
-    QPushButton*                   resetIconButton;
-    QPushButton*                   dateLowButton;
-    QPushButton*                   dateAvgButton;
-    QPushButton*                   dateHighButton;
+    QPushButton*                   iconButton       = nullptr;
+    QPushButton*                   resetIconButton  = nullptr;
+    QPushButton*                   dateLowButton    = nullptr;
+    QPushButton*                   dateAvgButton    = nullptr;
+    QPushButton*                   dateHighButton   = nullptr;
 
-    QDialogButtonBox*              buttons;
+    QDialogButtonBox*              buttons          = nullptr;
 
-    DTextEdit*                     nameEdit;
-    DTextEdit*                     descEdit;
-    QComboBox*                     favoriteTypeBox;
-    QDateTimeEdit*                 dateEdit;
-    DItemsList*                    urlsEdit;
-    QLabel*                        descLabel;
-    QLabel*                        nbImagesLabel;
-    QLabel*                        dateLabel;
-    QLabel*                        iconTextLabel;
-    QLabel*                        urlsLabel;
-    DAdjustableLabel*              helpLabel;
-    ShowfotoStackViewFavoriteList* list;
-    ShowfotoStackViewFavoriteItem* pitem;
+    DTextEdit*                     nameEdit         = nullptr;
+    DTextEdit*                     descEdit         = nullptr;
+    QComboBox*                     favoriteTypeBox  = nullptr;
+    QDateTimeEdit*                 dateEdit         = nullptr;
+    DItemsList*                    urlsEdit         = nullptr;
+    QLabel*                        descLabel        = nullptr;
+    QLabel*                        nbImagesLabel    = nullptr;
+    QLabel*                        dateLabel        = nullptr;
+    QLabel*                        iconTextLabel    = nullptr;
+    QLabel*                        urlsLabel        = nullptr;
+    DAdjustableLabel*              helpLabel        = nullptr;
+    ShowfotoStackViewFavoriteList* list             = nullptr;
+    ShowfotoStackViewFavoriteItem* pitem            = nullptr;
 };
 
-static Qt::SortOrder                        s_sortOrder(Qt::AscendingOrder);
-static ShowfotoStackViewList::StackViewRole s_sortRole(ShowfotoStackViewList::FileName);
+static Qt::SortOrder                        s_sortOrder = Qt::AscendingOrder;
+static ShowfotoStackViewList::StackViewRole s_sortRole  = ShowfotoStackViewList::FileName;
 
 ShowfotoStackViewFavoriteItemDlg::ShowfotoStackViewFavoriteItemDlg(ShowfotoStackViewFavoriteList* const list,
                                                                    bool create)
@@ -332,21 +308,13 @@ ShowfotoStackViewFavoriteItemDlg::ShowfotoStackViewFavoriteItemDlg(ShowfotoStack
 
     connect(d->dateHighButton, SIGNAL(clicked()),
             this, SLOT(slotDateHighButtonClicked()));
-
-    // --------------------------------------------------------
-
-    d->nameEdit->setFocus();
-
-    KConfigGroup group = KSharedConfig::openConfig()->group(objectName());
-    winId();
-    adjustSize();
-    DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
-    resize(windowHandle()->size());
 }
 
 ShowfotoStackViewFavoriteItemDlg::~ShowfotoStackViewFavoriteItemDlg()
 {
-    KConfigGroup group = KSharedConfig::openConfig()->group(objectName());
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group        = config->group(objectName());
+
     DXmlGuiWindow::saveWindowSize(windowHandle(), group);
 
     delete d;
@@ -519,13 +487,13 @@ void ShowfotoStackViewFavoriteItemDlg::setIconSize(int size)
 void ShowfotoStackViewFavoriteItemDlg::setSortOrder(int order)
 {
     s_sortOrder = (Qt::SortOrder)order;
-    d->urlsEdit->listView()->sortItems(s_sortRole + DItemsListView::Filename, s_sortOrder);
+    d->urlsEdit->listView()->sortItems((int)s_sortRole + (int)DItemsListView::Filename, s_sortOrder);
 }
 
 void ShowfotoStackViewFavoriteItemDlg::setSortRole(int role)
 {
     s_sortRole = (ShowfotoStackViewList::StackViewRole)role;
-    d->urlsEdit->listView()->sortItems(s_sortRole + DItemsListView::Filename, s_sortOrder);
+    d->urlsEdit->listView()->sortItems((int)s_sortRole + (int)DItemsListView::Filename, s_sortOrder);
 }
 
 void ShowfotoStackViewFavoriteItemDlg::setParentItem(ShowfotoStackViewFavoriteItem* const pitem)
@@ -749,7 +717,7 @@ void ShowfotoStackViewFavoriteItemDlg::slotDateAverageButtonClicked()
     QList<QDate> dates = getItemDates();
     qint64 julianDays  = 0;
 
-    Q_FOREACH (const QDate& date, dates)
+    for (const QDate& date : std::as_const(dates))
     {
         julianDays += date.toJulianDay();
     }
@@ -773,7 +741,7 @@ bool ShowfotoStackViewFavoriteItemDlg::itemIsLessThanHandler(const QTreeWidgetIt
 {
     int result = 0;
 
-    switch (s_sortRole + DItemsListView::Filename)
+    switch ((int)s_sortRole + (int)DItemsListView::Filename)
     {
         case DItemsListView::User1:     // Size
         {
@@ -820,6 +788,19 @@ void ShowfotoStackViewFavoriteItemDlg::slotHelp()
                                          QLatin1String("showfoto-stacktab"));
 }
 
+void ShowfotoStackViewFavoriteItemDlg::showEvent(QShowEvent* e)
+{
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group        = config->group(objectName());
+
+    DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size());
+
+    d->nameEdit->setFocus();
+
+    QDialog::showEvent(e);
+}
+
 } // namespace ShowFoto
 
 #include "moc_showfotostackviewfavoriteitemdlg.cpp"
