@@ -6,23 +6,13 @@
  * Date        : 2021-09-27
  * Description : Showfoto stack view favorites
  *
- * Copyright (C) 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef SHOWFOTO_STACK_VIEW_FAVORITES_H
-#define SHOWFOTO_STACK_VIEW_FAVORITES_H
+#pragma once
 
 // Qt includes
 
@@ -85,12 +75,14 @@ private Q_SLOTS:
     void slotSearchTextChanged(const SearchTextSettings& settings);
     void slotSearchResult(int found);
 
+private:
+
+    ShowfotoStackViewFavorites(QWidget*);
+
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace ShowFoto
-
-#endif // SHOWFOTO_STACK_VIEW_FAVORITES_H
