@@ -49,6 +49,7 @@ ShowfotoDelegate::~ShowfotoDelegate()
 void ShowfotoDelegate::setView(ShowfotoThumbnailBar* view)
 {
     Q_D(ShowfotoDelegate);
+
     setViewOnAllOverlays(view);
 
     if (d->currentView)
@@ -106,11 +107,6 @@ void ShowfotoDelegate::setModel(QAbstractItemModel* model)
     }
 }
 
-void ShowfotoDelegate::setSpacing(int spacing)
-{
-    ShowfotoItemViewDelegate::setSpacing(spacing);
-}
-
 QRect ShowfotoDelegate::pixmapRect() const
 {
     Q_D(const ShowfotoDelegate);
@@ -166,6 +162,7 @@ QPixmap ShowfotoDelegate::thumbnailPixmap(const QModelIndex& index) const
 void ShowfotoDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
     Q_D(const ShowfotoDelegate);
+
     ShowfotoItemInfo info     = ShowfotoItemModel::retrieveShowfotoItemInfo(index);
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(QLatin1String("ImageViewer Settings"));
@@ -297,14 +294,10 @@ void ShowfotoDelegate::setDefaultViewOptions(const QStyleOptionViewItem& option)
     ShowfotoItemViewDelegate::setDefaultViewOptions(option);
 }
 
-void ShowfotoDelegate::invalidatePaintingCache()
-{
-    ShowfotoItemViewDelegate::invalidatePaintingCache();
-}
-
 void ShowfotoDelegate::updateContentWidth()
 {
     Q_D(ShowfotoDelegate);
+
     d->contentWidth = d->thumbSize.size() + 2*d->radius;
 }
 
@@ -338,6 +331,7 @@ void ShowfotoDelegate::updateSizeRectsAndPixmaps()
 void ShowfotoDelegate::clearCaches()
 {
     Q_D(ShowfotoDelegate);
+
     ShowfotoItemViewDelegate::clearCaches();
     d->actualPixmapRectCache.clear();
 }
@@ -345,6 +339,7 @@ void ShowfotoDelegate::clearCaches()
 void ShowfotoDelegate::clearModelDataCaches()
 {
     Q_D(ShowfotoDelegate);
+
     d->actualPixmapRectCache.clear();
 }
 
@@ -381,6 +376,7 @@ QRect ShowfotoDelegate::actualPixmapRect(const QModelIndex& index) const
 void ShowfotoDelegate::updateActualPixmapRect(const QModelIndex& index, const QRect& rect)
 {
     Q_D(ShowfotoDelegate);
+
     QRect* const old = d->actualPixmapRectCache.object(index.row());
 
     if (!old || (*old != rect))
@@ -462,6 +458,7 @@ ShowfotoThumbnailDelegate::ShowfotoThumbnailDelegate(ShowfotoThumbnailBar* const
     : ShowfotoDelegate(*new ShowfotoThumbnailDelegatePrivate, parent)
 {
     Q_D(ShowfotoThumbnailDelegate);
+
     d->init(this);
 }
 
