@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GEO_MY_TREE_WIDGET_H
-#define DIGIKAM_GEO_MY_TREE_WIDGET_H
+#pragma once
 
 // Qt includes
 
@@ -41,11 +40,15 @@ protected:
 
     void startDrag(Qt::DropActions supportedActions)                 override;
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
     QMimeData*  mimeData(const QList<QTreeWidgetItem*>& items) const override;
+
 #else
+
     // cppcheck-suppress passedByValue
     QMimeData*  mimeData(const QList<QTreeWidgetItem*> items)  const override;      // clazy:exclude=function-args-by-ref
+
 #endif
 
     // cppcheck-suppress passedByValue
@@ -54,7 +57,5 @@ protected:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
-
-#endif // DIGIKAM_GEO_MY_TREE_WIDGET_H
