@@ -27,9 +27,11 @@
 
 // Local includes
 
+#include "digikam_debug.h"
 #include "facedetector.h"
 #include "faceutils.h"
 #include "previewloadthread.h"
+#include "scanstatefilter.h"
 #include "thumbnailloadthread.h"
 #include "workerobject.h"
 
@@ -102,8 +104,7 @@ Q_SIGNALS:
     friend class FacePipeline;
     void startProcess(const FacePipelineExtendedPackage::Ptr& package);
 
-    void accuracyAndModel(double accuracy, bool yolo);
-    void thresholdChanged(double threshold);
+    void accuracyAndModel(int detectAccuracy, FaceScanSettings::FaceDetectionModel detectModel, FaceScanSettings::FaceDetectionSize detectSize, int recognizeAccuracy, FaceScanSettings::FaceRecognitionModel recognizeModel);
 
 private:
 
