@@ -5,8 +5,9 @@
  *
  * Date        : 2023-05-15
  * Description : geolocation engine based on Marble.
+ *               (c) 2007-2022 Marble Team
+ *               https://invent.kde.org/education/marble/-/raw/master/data/credits_authors.html
  *
- * SPDX-FileCopyrightText: 2007-2022 Marble Team
  * SPDX-FileCopyrightText: 2023-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -289,12 +290,14 @@ O5mreaderIterateRet o5mreader_iterateDataSet(O5mreader* pReader, O5mreaderDatase
                 return O5MREADER_ITERATE_RET_ERR;
             }
 
-            fseek(
+            int ret = fseek(
                 pReader->f,
                 (pReader->current - ftell(pReader->f)) + pReader->offset,
                 SEEK_CUR
             );
 
+            (void)ret;
+
             pReader->offset = 0;
         }
 
@@ -312,12 +315,13 @@ O5mreaderIterateRet o5mreader_iterateDataSet(O5mreader* pReader, O5mreaderDatase
             return O5MREADER_ITERATE_RET_DONE;
         }
 
-        if (O5MREADER_DS_RESET == ds->type)
+        if      (O5MREADER_DS_RESET == ds->type)
         {
             o5mreader_reset(pReader);
         }
-
-        else if (0xf0 == ds->type) {}
+        else if (0xf0 == ds->type)
+        {
+        }
         else
         {
             if (o5mreader_readUInt(pReader, &pReader->offset) == O5MREADER_RET_ERR)
@@ -349,8 +353,6 @@ O5mreaderIterateRet o5mreader_iterateDataSet(O5mreader* pReader, O5mreaderDatase
             }
         }
     }
-
-
 }
 
 int o5mreader_thereAreNoMoreData(O5mreader* pReader)
