@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GPS_BOOKMARK_MODEL_HELPER_H
-#define DIGIKAM_GPS_BOOKMARK_MODEL_HELPER_H
+#pragma once
 
 // Qt includes
 
@@ -76,9 +75,7 @@ Q_SIGNALS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_GPS_BOOKMARK_MODEL_HELPER_H
