@@ -6,15 +6,14 @@
  * Date        : 2010-03-22
  * Description : A model for the view to display a list of items.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GPS_ITEM_DELEGATE_H
-#define DIGIKAM_GPS_ITEM_DELEGATE_H
+#pragma once
 
 // Qt includes
 
@@ -34,7 +33,7 @@ class GPSItemDelegate : public QItemDelegate
 public:
 
     explicit GPSItemDelegate(GPSItemList* const imageList, QObject* const parent = nullptr);
-    ~GPSItemDelegate() override;
+    ~GPSItemDelegate()                                                                                          override;
 
     void setThumbnailSize(const int size);
     int  getThumbnailSize()                                                                               const;
@@ -45,9 +44,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_GPS_ITEM_DELEGATE_H
