@@ -6,7 +6,7 @@
  * Date        : 2009-05-07
  * Description : Context menu for GPS list view.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2014 by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -34,13 +34,12 @@
 
 // Local includes
 
-#include "digikam_config.h"
+#include "digikam_debug.h"
 #include "gpsundocommand.h"
 #include "gpscommon.h"
 #include "gpsitemcontainer.h"
 #include "lookupfactory.h"
 #include "gpsbookmarkowner.h"
-#include "digikam_debug.h"
 
 namespace Digikam
 {
@@ -49,53 +48,37 @@ class Q_DECL_HIDDEN GPSItemListContextMenu::Private
 {
 public:
 
-    explicit Private()
-      : enabled                     (true),
-        actionBookmark              (nullptr),
-        bookmarkOwner               (nullptr),
-        actionCopy                  (nullptr),
-        actionPaste                 (nullptr),
-        actionPasteSwap             (nullptr),
-        actionRemoveCoordinates     (nullptr),
-        actionRemoveAltitude        (nullptr),
-        actionRemoveUncertainty     (nullptr),
-        actionRemoveSpeed           (nullptr),
-        actionLookupMissingAltitudes(nullptr),
-        imagesList                  (nullptr),
-        altitudeLookup              (),
-        altitudeUndoCommand         (nullptr),
-        altitudeRequestedCount      (0),
-        altitudeReceivedCount       (0)
-    {
-    }
+    Private() = default;
 
-    bool                     enabled;
+public:
 
-    QAction*                 actionBookmark;
-    GPSBookmarkOwner*        bookmarkOwner;
+    bool                     enabled                        = true;
 
-    QAction*                 actionCopy;
-    QAction*                 actionPaste;
-    QAction*                 actionPasteSwap;
-    QAction*                 actionRemoveCoordinates;
-    QAction*                 actionRemoveAltitude;
-    QAction*                 actionRemoveUncertainty;
-    QAction*                 actionRemoveSpeed;
-    QAction*                 actionLookupMissingAltitudes;
+    QAction*                 actionBookmark                 = nullptr;
+    GPSBookmarkOwner*        bookmarkOwner                  = nullptr;
 
-    GPSItemList*             imagesList;
+    QAction*                 actionCopy                     = nullptr;
+    QAction*                 actionPaste                    = nullptr;
+    QAction*                 actionPasteSwap                = nullptr;
+    QAction*                 actionRemoveCoordinates        = nullptr;
+    QAction*                 actionRemoveAltitude           = nullptr;
+    QAction*                 actionRemoveUncertainty        = nullptr;
+    QAction*                 actionRemoveSpeed              = nullptr;
+    QAction*                 actionLookupMissingAltitudes   = nullptr;
+
+    GPSItemList*             imagesList                     = nullptr;
 
     /// Altitude lookup
     QPointer<LookupAltitude> altitudeLookup;
-    GPSUndoCommand*          altitudeUndoCommand;
-    int                      altitudeRequestedCount;
-    int                      altitudeReceivedCount;
+    GPSUndoCommand*          altitudeUndoCommand            = nullptr;
+    int                      altitudeRequestedCount         = 0;
+    int                      altitudeReceivedCount          = 0;
 };
 
 GPSItemListContextMenu::GPSItemListContextMenu(GPSItemList* const imagesList,
                                                GPSBookmarkOwner* const bookmarkOwner)
     : QObject(imagesList),
-      d(new Private)
+      d      (new Private)
 {
     d->imagesList                   = imagesList;
 
@@ -160,21 +143,21 @@ bool GPSItemListContextMenu::eventFilter(QObject* watched, QEvent* event)
 
     if ((event->type() == QEvent::ContextMenu) && d->enabled)
     {
-        // enable or disable the actions
+        // Enable or disable the actions.
 
-        GPSItemModel* const imageModel           = d->imagesList->getModel();
+        GPSItemModel* const imageModel            = d->imagesList->getModel();
         QItemSelectionModel* const selectionModel = d->imagesList->getSelectionModel();
         const QList<QModelIndex> selectedIndices  = selectionModel->selectedRows();
         const int nSelected                       = selectedIndices.size();
 
-        // "copy" are only available for one selected image with geo data:
+        // "copy" are only available for one selected image with geo data.
 
-        bool copyAvailable                   = (nSelected == 1);
-        bool removeAltitudeAvailable         = false;
-        bool removeCoordinatesAvailable      = false;
-        bool removeUncertaintyAvailable      = false;
-        bool removeSpeedAvailable            = false;
-        bool lookupMissingAltitudesAvailable = false;
+        bool copyAvailable                        = (nSelected == 1);
+        bool removeAltitudeAvailable              = false;
+        bool removeCoordinatesAvailable           = false;
+        bool removeUncertaintyAvailable           = false;
+        bool removeSpeedAvailable                 = false;
+        bool lookupMissingAltitudesAvailable      = false;
 
         for (int i = 0 ; i < nSelected ; ++i)
         {
@@ -187,7 +170,7 @@ bool GPSItemListContextMenu::eventFilter(QObject* watched, QEvent* event)
                 copyAvailable                   &= itemHasCoordinates;
                 removeCoordinatesAvailable      |= itemHasCoordinates;
                 removeAltitudeAvailable         |= gpsData.getCoordinates().hasAltitude();
-                removeUncertaintyAvailable      |= gpsData.hasNSatellites() | gpsData.hasDop() | gpsData.hasFixType();
+                removeUncertaintyAvailable      |= (int)gpsData.hasNSatellites() | (int)gpsData.hasDop() | (int)gpsData.hasFixType();
                 removeSpeedAvailable            |= gpsData.hasSpeed();
                 lookupMissingAltitudesAvailable |= itemHasCoordinates && !gpsData.getCoordinates().hasAltitude();
             }
@@ -211,7 +194,7 @@ bool GPSItemListContextMenu::eventFilter(QObject* watched, QEvent* event)
         }
 
         // "paste" is only available if there is geo data in the clipboard
-        // and at least one photo is selected:
+        // and at least one photo is selected.
 
         bool pasteAvailable     = (nSelected >= 1);
         bool pasteSwapAvailable = true;
@@ -228,7 +211,7 @@ bool GPSItemListContextMenu::eventFilter(QObject* watched, QEvent* event)
         d->actionPaste->setEnabled(pasteAvailable);
         d->actionPasteSwap->setEnabled(pasteSwapAvailable);
 
-        // construct the context-menu:
+        // Construct the context-menu.
 
         QMenu* const menu = new QMenu(d->imagesList);
         menu->addAction(d->actionCopy);
@@ -259,13 +242,12 @@ bool GPSItemListContextMenu::eventFilter(QObject* watched, QEvent* event)
     {
         return QObject::eventFilter(watched, event);
     }
-
 }
 
 bool GPSItemListContextMenu::getCurrentItemPositionAndUrl(GPSDataContainer* const gpsInfo,
-                                                           QUrl* const itemUrl)
+                                                          QUrl* const itemUrl)
 {
-    // NOTE: currentIndex does not seem to work any more since we use KLinkItemSelectionModel
+    // NOTE: currentIndex does not seem to work any more since we use KLinkItemSelectionModel.
 
     GPSItemModel* const imageModel           = d->imagesList->getModel();
     QItemSelectionModel* const selectionModel = d->imagesList->getSelectionModel();
@@ -323,7 +305,7 @@ void GPSItemListContextMenu::pasteSwapActionTriggered()
 
 void GPSItemListContextMenu::pasteActionTriggered(bool swap)
 {
-    // extract the coordinates from the clipboard:
+    // Extract the coordinates from the clipboard.
 
     QClipboard* const clipboard = QApplication::clipboard();
     const QMimeData* mimedata   = clipboard->mimeData();
@@ -337,7 +319,7 @@ void GPSItemListContextMenu::pasteActionTriggered(bool swap)
         bool xmlOkay          = true;
         bool foundDoubleData  = false;
 
-        // code adapted from gpsdataparser.cpp
+        // Code adapted from gpsdataparser.cpp.
 
         QDomDocument gpxDoc(QLatin1String("gpx"));
 
@@ -395,7 +377,7 @@ void GPSItemListContextMenu::pasteActionTriggered(bool swap)
                         break;
                     }
 
-                    // Get metadata of way point (altitude and time stamp)
+                    // Get metadata of way point (altitude and time stamp).
 
                     for (QDomNode nWptMeta = wptElem.firstChild() ; !nWptMeta.isNull() ; nWptMeta = nWptMeta.nextSibling())
                     {
@@ -436,7 +418,7 @@ void GPSItemListContextMenu::pasteActionTriggered(bool swap)
         if (foundDoubleData)
         {
             QMessageBox::information(d->imagesList,
-                                     i18nc("@title:window", "GPS Sync"),
+                                     i18nc("@title:window", "Geolocation Editor"),
                                      i18n("Found more than one point on the clipboard - can only assign one point at a time."));
         }
     }
@@ -454,7 +436,7 @@ void GPSItemListContextMenu::pasteActionTriggered(bool swap)
         }
         else
         {
-            /// @todo this is legacy code from before we used geo-url
+            /// @todo this is legacy code from before we used geo-url.
 
             QLocale locale;
             QString cordText = textdata.trimmed();
@@ -484,7 +466,7 @@ void GPSItemListContextMenu::pasteActionTriggered(bool swap)
 
             while (!separators.isEmpty())
             {
-                parts = cordText.split(separators.takeFirst(), QT_SKIP_EMPTY_PARTS);
+                parts = cordText.split(separators.takeFirst(), Qt::SkipEmptyParts);
 
                 if ((parts.size() == 3) || (parts.size() == 2))
                 {
@@ -546,7 +528,7 @@ void GPSItemListContextMenu::pasteActionTriggered(bool swap)
 }
 
 void GPSItemListContextMenu::setGPSDataForSelectedItems(const GPSDataContainer& gpsData,
-                                                         const QString& undoDescription)
+                                                        const QString& undoDescription)
 {
     GPSItemModel* const imageModel            = d->imagesList->getModel();
     QItemSelectionModel* const selectionModel = d->imagesList->getSelectionModel();
@@ -569,6 +551,7 @@ void GPSItemListContextMenu::setGPSDataForSelectedItems(const GPSDataContainer&
     }
 
     undoCommand->setText(undoDescription);
+
     Q_EMIT signalUndoCommand(undoCommand);
 }
 
@@ -591,7 +574,7 @@ bool GPSItemListContextMenu::getCurrentPosition(GPSDataContainer* position, void
 
 void GPSItemListContextMenu::removeInformationFromSelectedImages(const GPSDataContainer::HasFlags flagsToClear, const QString& undoDescription)
 {
-    // enable or disable the actions
+    // Enable or disable the actions.
 
     GPSItemModel* const imageModel            = d->imagesList->getModel();
     QItemSelectionModel* const selectionModel = d->imagesList->getSelectionModel();
@@ -675,6 +658,7 @@ void GPSItemListContextMenu::removeInformationFromSelectedImages(const GPSDataCo
     if (undoCommand->affectedItemCount() > 0)
     {
         undoCommand->setText(undoDescription);
+
         Q_EMIT signalUndoCommand(undoCommand);
     }
     else
@@ -717,11 +701,11 @@ void GPSItemListContextMenu::slotLookupMissingAltitudes()
 /*
     const int nSelected                       = selectedIndices.size();
 */
-    // find the indices which have coordinates but no altitude
+    // Find the indices which have coordinates but no altitude.
 
     LookupAltitude::Request::List altitudeQueries;
 
-    Q_FOREACH (const QModelIndex& currentIndex, selectedIndices)
+    for (const QModelIndex& currentIndex : std::as_const(selectedIndices))
     {
         GPSItemContainer* const gpsItem = imageModel->itemFromIndex(currentIndex);
 
@@ -738,7 +722,7 @@ void GPSItemListContextMenu::slotLookupMissingAltitudes()
             continue;
         }
 
-        // the item has coordinates but no altitude, create a query
+        // The item has coordinates but no altitude, create a query.
 
         LookupAltitude::Request myLookup;
         myLookup.coordinates = coordinates;
@@ -761,6 +745,7 @@ void GPSItemListContextMenu::slotLookupMissingAltitudes()
             this, SLOT(slotAltitudeLookupDone()));
 
     Q_EMIT signalSetUIEnabled(false, this, QString::fromUtf8(SLOT(slotAltitudeLookupCancel())));
+
     Q_EMIT signalProgressSetup(altitudeQueries.count(), i18n("Looking up altitudes"));
 
     d->altitudeUndoCommand    = new GPSUndoCommand();
@@ -774,7 +759,7 @@ void GPSItemListContextMenu::slotAltitudeLookupReady(const QList<int>& readyRequ
 {
     GPSItemModel* const imageModel = d->imagesList->getModel();
 
-    Q_FOREACH (const int requestIndex, readyRequests)
+    for (const int requestIndex : std::as_const(readyRequests))
     {
         const LookupAltitude::Request myLookup  = d->altitudeLookup->getRequest(requestIndex);
         const QPersistentModelIndex markerIndex = myLookup.data.value<QPersistentModelIndex>();
@@ -813,14 +798,15 @@ void GPSItemListContextMenu::slotAltitudeLookupDone()
     if (requestStatus == LookupAltitude::StatusError)
     {
         const QString errorMessage = i18n("Altitude lookup failed:\n%1", d->altitudeLookup->errorMessage());
-        QMessageBox::information(d->imagesList, i18nc("@title:window", "GPS Sync"),errorMessage);
+        QMessageBox::information(d->imagesList, i18nc("@title:window", "Geolocation Editor"), errorMessage);
     }
 
     if (d->altitudeReceivedCount > 0)
     {
-        // at least some queries returned a result, save the undo command
+        // At least some queries returned a result, save the undo command.
 
         d->altitudeUndoCommand->setText(i18n("Altitude looked up"));
+
         Q_EMIT signalUndoCommand(d->altitudeUndoCommand);
     }
     else
@@ -843,3 +829,5 @@ void GPSItemListContextMenu::slotAltitudeLookupCancel()
 }
 
 } // namespace Digikam
+
+#include "moc_gpsitemlistcontextmenu.cpp"
