@@ -40,16 +40,8 @@ namespace Digikam
 {
 
 ItemViewImportDelegatePrivate::ItemViewImportDelegatePrivate()
-    : spacing      (0),
-      thumbSize    (ThumbnailSize(0)),
-      q            (nullptr),
-      displayWidget(nullptr),
-      radius       (3),       // painting constants
-      margin       (5)
 {
     makeStarPolygon();
-
-    ratingPixmaps = QVector<QPixmap>(10);
 }
 
 void ItemViewImportDelegatePrivate::init(ItemViewImportDelegate* const _q, QWidget* const _widget)
@@ -79,13 +71,15 @@ void ItemViewImportDelegatePrivate::makeStarPolygon()
 // ---- ItemViewImportDelegate -----------------------------------------------
 
 ItemViewImportDelegate::ItemViewImportDelegate(QWidget* const parent)
-    : DItemDelegate(parent), d_ptr(new ItemViewImportDelegatePrivate)
+    : DItemDelegate(parent),
+      d_ptr        (new ItemViewImportDelegatePrivate)
 {
     d_ptr->init(this, parent);
 }
 
 ItemViewImportDelegate::ItemViewImportDelegate(ItemViewImportDelegatePrivate& dd, QWidget* const parent)
-    : DItemDelegate(parent), d_ptr(&dd)
+    : DItemDelegate(parent),
+      d_ptr        (&dd)
 {
     d_ptr->init(this, parent);
 }
@@ -198,7 +192,8 @@ bool ItemViewImportDelegate::acceptsToolTip(const QPoint&, const QRect& visualRe
     return true;
 }
 
-bool ItemViewImportDelegate::acceptsActivation(const QPoint& , const QRect& visualRect, const QModelIndex&, QRect* retRect) const
+bool ItemViewImportDelegate::acceptsActivation(const QPoint&, const QRect& visualRect,
+                                               const QModelIndex&, QRect* retRect) const
 {
     if (retRect)
     {
@@ -261,7 +256,9 @@ void ItemViewImportDelegate::invalidatePaintingCache()
     Q_EMIT visualChange();
 }
 
-QRect ItemViewImportDelegate::drawThumbnail(QPainter* p, const QRect& thumbRect, const QPixmap& background,
+QRect ItemViewImportDelegate::drawThumbnail(QPainter* p,
+                                            const QRect& thumbRect,
+                                            const QPixmap& background,
                                             const QPixmap& thumbnail) const
 {
     p->drawPixmap(0, 0, background);
@@ -292,8 +289,11 @@ QRect ItemViewImportDelegate::drawThumbnail(QPainter* p, const QRect& thumbRect,
     return actualPixmapRect;
 }
 
-void ItemViewImportDelegate::drawRating(QPainter* p, const QModelIndex& index, const QRect& ratingRect,
-                                       int rating, bool isSelected) const
+void ItemViewImportDelegate::drawRating(QPainter* p,
+                                        const QModelIndex& index,
+                                        const QRect& ratingRect,
+                                        int rating,
+                                        bool isSelected) const
 {
     Q_D(const ItemViewImportDelegate);
 
@@ -360,7 +360,7 @@ void ItemViewImportDelegate::drawImageSize(QPainter* p, const QRect& dimsRect, c
     {
         p->setFont(d->fontXtra);
         QString mpixels, resolution;
-        mpixels = QLocale().toString(dims.width()*dims.height()/1000000.0, 'f', 1);
+        mpixels = QLocale().toString(dims.width() * dims.height() / 1000000.0, 'f', 1);
 
         if (dims.isValid())
         {
@@ -384,8 +384,10 @@ void ItemViewImportDelegate::drawFileSize(QPainter* p, const QRect& r, qlonglong
     p->drawText(r, Qt::AlignCenter, ItemPropertiesTab::humanReadableBytesCount(bytes));
 }
 
-void ItemViewImportDelegate::drawTags(QPainter* p, const QRect& r, const QString& tagsString,
-                                     bool isSelected) const
+void ItemViewImportDelegate::drawTags(QPainter* p,
+                                      const QRect& r,
+                                      const QString& tagsString,
+                                      bool isSelected) const
 {
     Q_D(const ItemViewImportDelegate);
 
@@ -421,19 +423,29 @@ void ItemViewImportDelegate::drawPickLabelIcon(QPainter* p, const QRect& r, int
     }
 }
 
-void ItemViewImportDelegate::drawColorLabelRect(QPainter* p, const QStyleOptionViewItem& option,
-                                                bool isSelected, int colorId) const
+void ItemViewImportDelegate::drawColorLabelLine(QPainter* p, const QRect& pixRect, int colorId) const
 {
-    Q_D(const ItemViewImportDelegate);
-    Q_UNUSED(option);
-    Q_UNUSED(isSelected);
-
     if (colorId > NoColorLabel)
     {
-        // This draw a simple rectangle around item.
+        // This draw a line under the thumbnail.
 
-        p->setPen(QPen(ColorLabelWidget::labelColor((ColorLabel)colorId), 5, Qt::SolidLine));
-        p->drawRect(3, 3, d->rect.width()-7, d->rect.height()-7);
+        QLinearGradient gradient(pixRect.x(), 0, pixRect.x() + pixRect.width(), 1);
+        QColor color(ColorLabelWidget::labelColor((ColorLabel)colorId));
+
+        color.setAlphaF(0.2);
+        gradient.setColorAt(0.0, color);
+        gradient.setColorAt(1.0, color);
+
+        color.setAlphaF(1.0);
+        gradient.setColorAt(0.3, color);
+        gradient.setColorAt(0.7, color);
+
+        p->setPen(QPen(QBrush(gradient), 5));
+
+        p->drawLine(pixRect.x(),
+                    pixRect.y() + pixRect.height() - 3,
+                    pixRect.x() + pixRect.width(),
+                    pixRect.y() + pixRect.height() - 3);
     }
 }
 
@@ -501,7 +513,8 @@ void ItemViewImportDelegate::drawLockIndicator(QPainter* p, const QRect& r, int
     p->setOpacity(op);
 }
 
-void ItemViewImportDelegate::drawFocusRect(QPainter* p, const QStyleOptionViewItem& option,
+void ItemViewImportDelegate::drawFocusRect(QPainter* p,
+                                           const QStyleOptionViewItem& option,
                                            bool isSelected) const
 {
     Q_D(const ItemViewImportDelegate);
@@ -511,12 +524,14 @@ void ItemViewImportDelegate::drawFocusRect(QPainter* p, const QStyleOptionViewIt
         p->setPen(QPen(isSelected ? qApp->palette().color(QPalette::HighlightedText)
                                   : qApp->palette().color(QPalette::Text),
                        1, Qt::DotLine));
-        p->drawRect(1, 1, d->rect.width()-3, d->rect.height()-3);
+        p->drawRect(1, 1, d->rect.width() - 3, d->rect.height() - 3);
     }
 }
 
-void ItemViewImportDelegate::drawGroupIndicator(QPainter* p, const QRect& r,
-                                                int numberOfGroupedImages, bool open) const
+void ItemViewImportDelegate::drawGroupIndicator(QPainter* p,
+                                                const QRect& r,
+                                                int numberOfGroupedImages,
+                                                bool open) const
 {
     if (numberOfGroupedImages)
     {
@@ -548,7 +563,7 @@ void ItemViewImportDelegate::drawMouseOverRect(QPainter* p, const QStyleOptionVi
     if (option.state & QStyle::State_MouseOver)
     {
         p->setPen(QPen(option.palette.color(QPalette::Highlight), 3, Qt::SolidLine));
-        p->drawRect(1, 1, d->rect.width()-3, d->rect.height()-3);
+        p->drawRect(1, 1, d->rect.width() - 3, d->rect.height() - 3);
     }
 }
 
@@ -609,13 +624,13 @@ void ItemViewImportDelegate::prepareBackground()
         d->regPixmap.fill(qApp->palette().color(QPalette::Base));
         QPainter p1(&d->regPixmap);
         p1.setPen(qApp->palette().color(QPalette::Midlight));
-        p1.drawRect(0, 0, d->rect.width()-1, d->rect.height()-1);
+        p1.drawRect(0, 0, d->rect.width() - 1, d->rect.height() - 1);
 
         d->selPixmap = QPixmap(d->rect.width(), d->rect.height());
         d->selPixmap.fill(qApp->palette().color(QPalette::Highlight));
         QPainter p2(&d->selPixmap);
         p2.setPen(qApp->palette().color(QPalette::Midlight));
-        p2.drawRect(0, 0, d->rect.width()-1, d->rect.height()-1);
+        p2.drawRect(0, 0, d->rect.width() - 1, d->rect.height() - 1);
     }
 }
 
@@ -662,7 +677,7 @@ void ItemViewImportDelegate::prepareRatingPixmaps(bool composeOverBackground)
         basePix    = basePix.scaled(d->ratingRect.size() * dpr);
         basePix.setDevicePixelRatio(dpr);
 
-        for (int rating = 1; rating <= 5; ++rating)
+        for (int rating = 1 ; rating <= 5 ; ++rating)
         {
             // we store first the 5 regular, then the 5 selected pixmaps, for simplicity
 
@@ -689,7 +704,8 @@ void ItemViewImportDelegate::prepareRatingPixmaps(bool composeOverBackground)
 
             // move painter while drawing polygons
 
-            painter.translate( lround((d->ratingRect.width() - d->margin - rating*(d->starPolygonSize.width()+1))/2.0) + 2, 1 );
+            painter.translate( lround((d->ratingRect.width() - d->margin - rating *
+                                      (d->starPolygonSize.width() + 1)) / 2.0) + 2, 1 );
 
             for (int s = 0 ; s < rating ; ++s)
             {
