@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_IMPORT_STACKED_VIEW_H
-#define DIGIKAM_IMPORT_STACKED_VIEW_H
+#pragma once
 
 // Qt includes
 
@@ -113,11 +112,11 @@ public:
     void   setZoomFactor(double z);
     void   setZoomFactorSnapped(double z);
 
-    bool   maxZoom()    const;
-    bool   minZoom()    const;
-    double zoomFactor() const;
-    double zoomMin()    const;
-    double zoomMax()    const;
+    bool   maxZoom()                        const;
+    bool   minZoom()                        const;
+    double zoomFactor()                     const;
+    double zoomMin()                        const;
+    double zoomMax()                        const;
 
 Q_SIGNALS:
 
@@ -151,9 +150,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_IMPORT_STACKED_VIEW_H
