@@ -43,7 +43,7 @@ public:
 
 Q_SIGNALS:
 
-    void signalFinished(const QImage&);
+    void signalFinished(const ItemInfo&, const QImage&);
 
 protected:
 
