@@ -53,7 +53,7 @@ QString AssignedBatchTools::targetSuffix(bool* const extSet) const
 {
     QString suffix;
 
-    Q_FOREACH (const BatchToolSet& set, m_toolsList)
+    for (const BatchToolSet& set : std::as_const(m_toolsList))
     {
         BatchTool* const tool = BatchToolsFactory::instance()->findTool(set.name, set.group);
 
