@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_QUEUE_LIST_H
-#define DIGIKAM_BQM_QUEUE_LIST_H
+#pragma once
 
 // Qt includes
 
@@ -79,7 +78,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 
 private:
 
@@ -94,6 +93,16 @@ class QueueListView : public QTreeWidget
 {
     Q_OBJECT
 
+public:
+
+    enum ItemListType
+    {
+        Pending = 0,    ///< Items from the list not yet processed.
+        Selected,       ///< Items from the list selected.
+        All             ///< All items from the list.
+    };
+    Q_ENUM(ItemListType)
+
 public:
 
     explicit QueueListView(QWidget* const parent);
@@ -104,7 +113,7 @@ public:
     void removeItemByInfo(const ItemInfo& info);
     void removeItemById(qlonglong id);
 
-    ItemInfoList pendingItemsList();
+    ItemInfoList itemsList(ItemListType type);
     int          pendingItemsCount();
     int          pendingTasksCount();
 
@@ -184,9 +193,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_BQM_QUEUE_LIST_H
