@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SETUP_MISC_H
-#define DIGIKAM_SETUP_MISC_H
+#pragma once
 
 // Qt includes
 
@@ -58,9 +57,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SETUP_MISC_H
