@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SETUP_LIGHT_TABLE_H
-#define DIGIKAM_SETUP_LIGHT_TABLE_H
+#pragma once
 
 // Qt includes
 
@@ -40,9 +39,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SETUP_LIGHT_TABLE_H
