@@ -46,24 +46,15 @@ OsxCodeName
 ORIG_PATH="$PATH"
 ORIG_WD="`pwd`"
 
-export PATH=$INSTALL_PREFIX/bin:/$INSTALL_PREFIX/sbin:/$INSTALL_PREFIX/libexec/qt5/bin:$ORIG_PATH
+export PATH=$INSTALL_PREFIX/bin:/$INSTALL_PREFIX/sbin:/$INSTALL_PREFIX/libexec/qt$DK_QTVERSION/bin:$ORIG_PATH:/$INSTALL_PREFIX/libexec/gnubin
+echo "PATH=$PATH"
+export DYLD_LIBRARY_PATH=$DYLD_LIBRARY_PATH/$INSTALL_PREFIX
+echo "DYLD_LIBRARY_PATH=$DYLD_LIBRARY_PATH"
 
 #################################################################################################
 # Check if /opt exists and standard Macports install path
 
-if [ -d "/opt" ] ; then
-
-    if [ -d "/opt/local" ] ; then
-
-        echo "---------- A standard Macports install exists on /opt/local."
-        echo "           To prevent wrong links from this bundle to this repository"
-        echo "           this one must be disabled (moving to /opt/local.back for ex)."
-        echo "---------- Aborting..."
-        exit;
-
-    fi
-
-else
+if [ ! -d "/opt" ] ; then
 
     echo "---------- /opt do not exist, creating"
 
@@ -181,11 +172,11 @@ if [[ $CONTINUE_INSTALL == 0 ]]; then
 
     echo "---------- Configuring MacPorts"
 
-    ./configure --prefix="$INSTALL_PREFIX" \
+    ./configure --prefix="$INSTALL_PREFIX"                             \
                 --with-applications-dir="$INSTALL_PREFIX/Applications" \
-                --with-no-root-privileges \
-                --with-install-user="$(id -n -u)" \
-                --with-install-group="$(id -n -g)" 
+                --with-no-root-privileges                              \
+                --with-install-user="$(id -n -u)"                      \
+                --with-install-group="$(id -n -g)"
 
     echo -e "\n\n"
 
@@ -205,15 +196,15 @@ macosx_deployment_target $OSX_MIN_TARGET
 build_arch $ARCH_TARGET
 EOF
 
-    if [[ $ARCH_TARGET = "arm64" ]] ; then
-
-        # No need to build with both architectures embeded (x86 and ARM) for Apple Silicon target
-
-        cat << EOF >> "$INSTALL_PREFIX/etc/macports/variants.conf"
-+universal
-EOF
-
-    fi
+#    if [[ $ARCH_TARGET = "arm64" ]] ; then
+#
+#        # Build with both architectures embeded (x86 and ARM) for Apple Silicon target
+#
+#        cat << EOF >> "$INSTALL_PREFIX/etc/macports/variants.conf"
+#+universal
+#EOF
+#
+#    fi
 
 fi
 
@@ -234,13 +225,33 @@ if [[ $CONTINUE_INSTALL == 0 ]]; then
 
 fi
 
+#################################################################################################
+
+# Create the build dir for the 3rdparty deps compiled with CMake
+
+if [ ! -d $BUILDING_DIR ] ; then
+
+    mkdir $BUILDING_DIR
+
+fi
+
+if [ ! -d $DOWNLOAD_DIR ] ; then
+
+    mkdir $DOWNLOAD_DIR
+
+fi
+
+cd $BUILDING_DIR
+
+rm -rf $BUILDING_DIR/* || true
+
 #################################################################################################
 # Dependencies build and installation
 
 echo -e "\n"
 echo "---------- Building digiKam dependencies with Macports"
 
-# With OSX less than El Capitan, we need a more recent Clang compiler than one provided by XCode.
+# With MacOS less than El Capitan, we need a more recent Clang compiler than one provided by XCode.
 # This only concern x86_64 architecture.
 
 if [[ $MAJOR_OSX_VERSION -lt 11 && $MINOR_OSX_VERSION -lt 10 ]]; then
@@ -262,90 +273,86 @@ fi
 
 echo -e "MariaDB Variant=$MP_MARIADB_VARIANT\n"
 
-port install \
-             cctools +xcode \
-             cmake \
-             ccache \
-             libpng \
-             jpeg \
-             tiff \
-             boost \
-             eigen3 \
-             gettext \
-             libusb \
-             libgphoto2 \
-             jasper \
-             lcms2 \
-             expat \
-             libxml2 \
-             libxslt \
-             libical \
-             bison \
-             py38-lxml \
-             x265 \
-             libde265 \
-             libheif \
-             aom \
-             ffmpeg \
-             wget +ssl \
-             qt5-qtbase \
-             qt5-qtdeclarative \
-             qt5-qtmacextras \
-             qt5-qtquickcontrols \
-             qt5-qtxmlpatterns \
-             qt5-qtsvg \
-             qt5-qttools \
-             qt5-qttranslations \
-             qt5-qtimageformats \
-             qt5-qtmultimedia
-             qt5-qtnetworkauth \
-             qt5-sqlite-plugin \
-             qt5-mysql-plugin $MP_MARIADB_VARIANT
+# To fix broken ports with m4 tool detection.
 
-port deactivate boost
+port install m4
 
-if [[ $DK_QTWEBENGINE = 1 ]] ; then
+if [ ! -f $INSTALL_PREFIX/bin/m4 ] ; then
 
-    port install qt5-qtwebengine
-
-else
-
-    port install qt5-qtwebkit
+    cp -f $INSTALL_PREFIX/libexec/gnubin/m4 $INSTALL_PREFIX/bin/
 
 fi
 
-port activate boost
 
-# port broken since a while. check later
-#             sane-backends \
+port install git -perl5_34      # See bug https://trac.macports.org/ticket/70547
+port install cctools +xcode
+port install cmake
+port install ccache
+port install libpng
+port install jpeg
+port install tiff
+port install eigen3
+port install gettext
+port install vala -valadoc      # See bug https://trac.macports.org/ticket/70643
+port install wget +ssl
+port install jasper
+port install lcms2
+port install expat
+port install libxml2
+port install libxslt
+port install libical
+port install bison
+port install py38-lxml
+port install x265
+port install libde265
+port install libfdk-aac
+port install lame
+port install speex
+port install libtheora
+port install xvid
+port install libass
+port install opus-tools
+port install libvpx
+port install x264
+port install aom
+port install libusb
+port install libgphoto2
 
-echo -e "\n"
+port install libheif +x265 -tests -rav1e -kvazaar
+port install ffmpeg6 +gpl2 +nonfree
 
-echo -e "---------- Compilation logs of Macports packages with suspicious installation\n"
-find $INSTALL_PREFIX/var/macports/logs/ -name main.log
-echo -e "\n----------"
+if [ ! -f $INSTALL_PREFIX/bin/ffmpeg ] ; then
 
-echo -e "\n"
-
-#################################################################################################
-
-# Create the build dir for the 3rdparty deps
-
-if [ ! -d $BUILDING_DIR ] ; then
-
-    mkdir $BUILDING_DIR
+    # Need to push ffmpeg6 from $INSTALL_PREFIX/libexec/ffmpeg6 to $INSTALL_PREFIX
+    cp -r $INSTALL_PREFIX/libexec/ffmpeg6/include $INSTALL_PREFIX
+    cp -r $INSTALL_PREFIX/libexec/ffmpeg6/lib     $INSTALL_PREFIX
+    mv $INSTALL_PREFIX/bin/ffmpeg6 $INSTALL_PREFIX/bin/ffmpeg
 
 fi
 
-if [ ! -d $DOWNLOAD_DIR ] ; then
+port install qt$DK_QTVERSION-qtbase -examples -tests
+port install qt$DK_QTVERSION-qtdeclarative -examples -tests
 
-    mkdir $DOWNLOAD_DIR
+if [[ $DK_QTVERSION = 5 ]] ; then
 
+    port install qt$DK_QTVERSION-qtmacextras -examples -tests
+    port install qt$DK_QTVERSION-qtquickcontrols -examples -tests
+    port install qt$DK_QTVERSION-qtxmlpatterns -examples -tests
 fi
 
-cd $BUILDING_DIR
+port install qt$DK_QTVERSION-qtscxml -examples -tests
+port install qt$DK_QTVERSION-qtspeech -examples -tests
+port install qt$DK_QTVERSION-qtsvg -examples -tests
+port install qt$DK_QTVERSION-qttools -examples -tests
+port install qt$DK_QTVERSION-qttranslations
+port install qt$DK_QTVERSION-qtimageformats -examples -tests
+port install qt$DK_QTVERSION-qtmultimedia -examples -tests
+port install qt$DK_QTVERSION-qtnetworkauth -examples -tests
+port install qt$DK_QTVERSION-sqlite-plugin
+port install qt$DK_QTVERSION-mysql-plugin $MP_MARIADB_VARIANT
+port install qt$DK_QTVERSION-qtwebengine -examples -tests
 
-rm -rf $BUILDING_DIR/* || true
+port install boost
 
 cmake $ORIG_WD/../3rdparty \
        -DCMAKE_INSTALL_PREFIX:PATH=$INSTALL_PREFIX \
@@ -355,17 +362,19 @@ cmake $ORIG_WD/../3rdparty \
        -DKP_VERSION=$DK_KP_VERSION \
        -DKDE_VERSION=$DK_KDE_VERSION \
        -DENABLE_QTVERSION=$DK_QTVERSION \
-       -DENABLE_QTWEBENGINE=$DK_QTWEBENGINE \
+       -DDK_APPLE_PACKAGE_MANAGER=$DK_APPLE_PACKAGE_MANAGER \
+       -DARCH_TARGET=$ARCH_TARGET \
        -Wno-dev
 
-if [[ $DK_QTWEBENGINE = 0 ]] ; then
-    cmake --build . --config RelWithDebInfo --target ext_qtwebkit    -- -j$CPU_CORES
-fi
-
 cmake --build . --config RelWithDebInfo --target ext_opencv      -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_imagemagick -- -j$CPU_CORES
-cmake --build . --config RelWithDebInfo --target ext_libjxl      -- -j$CPU_CORES
-cmake --build . --config RelWithDebInfo --target ext_libavif     -- -j$CPU_CORES
+
+port install libjxl
+port install libavif -docs -tests
+
+# for rll.py script.
+port install python27
+port select --set python2 python27
 
 #################################################################################################
 
