@@ -3,7 +3,7 @@
 # Script to build extra libraries using MacPorts env.
 # This script must be run as sudo
 #
-# SPDX-FileCopyrightText: 2015-2023 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
 # SPDX-License-Identifier: BSD-3-Clause
 #
@@ -45,7 +45,7 @@ OsxCodeName
 ORIG_PATH="$PATH"
 ORIG_WD="`pwd`"
 
-export PATH=$INSTALL_PREFIX/bin:/$INSTALL_PREFIX/sbin:/$INSTALL_PREFIX/libexec/qt5/bin:$ORIG_PATH
+export PATH=$INSTALL_PREFIX/bin:/$INSTALL_PREFIX/sbin:/$INSTALL_PREFIX/libexec/qt$DK_QTVERSION/bin:$ORIG_PATH
 
 #################################################################################################
 
@@ -67,14 +67,15 @@ cmake $ORIG_WD/../3rdparty \
        -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR \
        -DKA_VERSION=$DK_KA_VERSION \
        -DKP_VERSION=$DK_KP_VERSION \
-       -DKF5_VERSION=$DK_KF5_VERSION \
+       -DKDE_VERSION=$DK_KDE_VERSION \
        -DENABLE_QTVERSION=$DK_QTVERSION \
-       -DENABLE_QTWEBENGINE=$DK_QTWEBENGINE \
+       -DDK_APPLE_PACKAGE_MANAGER=$DK_APPLE_PACKAGE_MANAGER \
+       -DARCH_TARGET=$ARCH_TARGET \
        -Wno-dev
 
 # NOTE: The order to compile each component here is very important.
 
-# core KF5 frameworks dependencies
+# core KF frameworks dependencies
 cmake --build . --config RelWithDebInfo --target ext_extra-cmake-modules -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_kconfig             -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_breeze-icons        -- -j$CPU_CORES
@@ -92,26 +93,32 @@ cmake --build . --config RelWithDebInfo --target ext_kguiaddons          -- -j$C
 cmake --build . --config RelWithDebInfo --target ext_kwidgetsaddons      -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_kitemviews          -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_kcompletion         -- -j$CPU_CORES
+
+if [[ $DK_QTVERSION == 6 ]] ; then
+
+    cmake --build . --config RelWithDebInfo --target ext_kcolorscheme           -- -j$CPU_CORES
+
+fi
+
 cmake --build . --config RelWithDebInfo --target ext_kconfigwidgets      -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_kiconthemes         -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_kservice            -- -j$CPU_CORES
-cmake --build . --config RelWithDebInfo --target ext_kglobalaccel        -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_kxmlgui             -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_kbookmarks          -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_kimageformats       -- -j$CPU_CORES
 
 # Extra support for digiKam
 
+if [[ $DK_QTVERSION == 6 ]] ; then
+
+    cmake --build . --config RelWithDebInfo --target ext_sonnet              -- -j$CPU_CORES
+    cmake --build . --config RelWithDebInfo --target ext_ktextwidgets        -- -j$CPU_CORES
+
+fi
+
 # libksane support
 #cmake --build . --config RelWithDebInfo --target ext_libksane            -- -j$CPU_CORES
 
-# Geolocation support
-cmake --build . --config RelWithDebInfo --target ext_marble              -- -j$CPU_CORES
-
-# Marble install shared lib at wrong place.
-mv $INSTALL_PREFIX/Marble.app/Contents/MacOS/lib/libastro*  $INSTALL_PREFIX/lib
-mv $INSTALL_PREFIX/Marble.app/Contents/MacOS/lib/libmarble* $INSTALL_PREFIX/lib
-
 # Calendar support
 cmake --build . --config RelWithDebInfo --target ext_kcalendarcore       -- -j$CPU_CORES
 
