@@ -75,8 +75,17 @@ Applications/digiKam.org \
 "
 
 # Other apps - non-MacOS binaries & libraries to be included with required dylibs
+
+if [[ $ARCH_TARGET = "x86_64" ]] ; then
+    QT_PLUGIN_EXT="so"
+else
+    QT_PLUGIN_EXT="dylib"
+fi
+
+# Note: lib/plugins/styles/ files are *.so in both architectures. Why this mess?
+
 OTHER_APPS="\
-lib/plugins/imageformats/*.so \
+lib/plugins/imageformats/*.$QT_PLUGIN_EXT \
 lib/plugins/styles/*.so \
 lib/plugins/digikam/bqm/*.so \
 lib/plugins/digikam/generic/*.so \
@@ -90,28 +99,51 @@ lib/mariadb$MARIADB_SUFFIX/bin/mysqladmin \
 lib/mariadb$MARIADB_SUFFIX/bin/mysqltest \
 lib/mariadb$MARIADB_SUFFIX/mysql/*.dylib \
 lib/mariadb$MARIADB_SUFFIX/plugin/*.so \
-bin/kbuildsycoca5 \
-bin/solid-hardware5 \
+bin/kbuildsycoca$DK_QTVERSION \
+bin/solid-hardware$DK_QTVERSION \
 bin/ffmpeg \
-libexec/qt5/plugins/imageformats/*.dylib \
-libexec/qt5/plugins/sqldrivers/*.dylib \
-libexec/qt5/plugins/printsupport/*.dylib \
-libexec/qt5/plugins/platforms/*.dylib \
-libexec/qt5/plugins/platformthemes/*.dylib \
-libexec/qt5/plugins/iconengines/*.dylib \
-libexec/qt5/plugins/generic/*.dylib \
-libexec/qt5/plugins/styles/*.dylib \
-libexec/qt5/plugins/bearer/*.dylib \
+libexec/qt$DK_QTVERSION/plugins/imageformats/*.dylib \
+libexec/qt$DK_QTVERSION/plugins/sqldrivers/*.dylib \
+libexec/qt$DK_QTVERSION/plugins/platforms/*.dylib \
+libexec/qt$DK_QTVERSION/plugins/iconengines/*.dylib \
+libexec/qt$DK_QTVERSION/plugins/generic/*.dylib \
+libexec/qt$DK_QTVERSION/plugins/styles/*.dylib \
 "
 
+if [[ $DK_QTVERSION == 5 ]] ; then
+
+    # Qt5 specific plugins
+
+    OTHER_APPS=$OTHER_APPS"\
+    libexec/qt$DK_QTVERSION/plugins/audio/*.dylib \
+    libexec/qt$DK_QTVERSION/plugins/bearer/*.dylib \
+    libexec/qt$DK_QTVERSION/plugins/printsupport/*.dylib \
+    libexec/qt$DK_QTVERSION/plugins/platformthemes/*.dylib \
+    "
+
+else
+
+    # Qt6 specific plugins
+
+    OTHER_APPS=$OTHER_APPS"\
+    libexec/qt$DK_QTVERSION/plugins/multimedia/*.dylib \
+    libexec/qt$DK_QTVERSION/plugins/tls/*.dylib \
+    "
+
+fi
+
 #lib/sane/*.so \
 
 binaries="$OTHER_APPS"
 
 # Additional Files/Directories - to be copied recursively but not checked for dependencies
-# Note: dSYM directories are copied as well and cleaned later if debug symbols must be removed in final bundle.
+#
+# NOTE: dSYM directories are copied as well and cleaned later if debug symbols must be removed in final bundle.
+#
+#       QtWebEngine runtime process and binary archives (.pak) are located in libexec/qt$DK_QTVERSION/lib/QtWebEngineCore.framework/
+#
 OTHER_DIRS="\
-libexec/qt5/translations \
+libexec/qt$DK_QTVERSION/translations \
 lib/libdigikam*.dSYM \
 lib/plugins \
 lib/libgphoto2 \
@@ -125,18 +157,34 @@ etc/ImageMagick* \
 etc/mariadb$MARIADB_SUFFIX \
 "
 
-#etc/sane.d \
+if [[ $DK_QTVERSION == 6 ]] ; then
+
+    OTHER_DIRS=$OTHER_DIRS"\
+    libexec/qt$DK_QTVERSION/lib/QtWebEngineCore.framework \
+    "
+
+fi
 
 # Additional Data Directories - to be copied recursively
 OTHER_DATA="\
-share/applications \
 share/opencv4 \
 share/k* \
-share/lensfun \
 share/mime \
 Library/Application/ \
+share/applications \
+lensfun \
 "
 
+if [[ $DK_QTVERSION == 6 ]] ; then
+
+    # NOTE: Qt5Curve is located in Library/Application
+
+    OTHER_DATA=$OTHER_DATA"\
+    share/QtCurve
+    "
+
+fi
+
 # Packaging tool paths
 PACKAGESBUILD="/usr/local/bin/packagesbuild"
 RECURSIVE_LIBRARY_LISTER="$BUILDDIR/rll.py"
@@ -259,6 +307,10 @@ for path in $OTHER_DIRS ; do
     cp -aH "$INSTALL_PREFIX/$path" "$TEMPROOT/$dir/"
 done
 
+echo -e "------------- Move libgphoto2 drivers\n"
+
+find "$TEMPROOT/lib/libgphoto2"      -name "*.so" -type f -exec mv {} "$TEMPROOT/lib/libgphoto2" \;
+find "$TEMPROOT/lib/libgphoto2_port" -name "*.so" -type f -exec mv {} "$TEMPROOT/lib/libgphoto2_port" \;
 
 echo "---------- Copying data files..."
 
@@ -275,24 +327,15 @@ done
 mkdir -p "$TEMPROOT/digikam.app/Contents/Resources/icons/"
 cp -a "$INSTALL_PREFIX/share/icons/hicolor" "$TEMPROOT/digikam.app/Contents/Resources/icons/"
 
-echo "---------- Copying Qt Web Backend files..."
+# Copy the Qt configuration ini file
 
-# Qt Web framework bin data files.
-# NOTE: Since Qt 5.15.0, QtWebEngine runtime process is now located in
-#       libexec/qt5/lib/QtWebEngineCore.framework/Versions/5/Helpers/QtWebEngineProcess.app/Contents/MacOS
-#       instead of libexec/qt5/libexec/. No needs to make extra rules for this runtime process.
+if [[ $DK_QTVERSION = 5 ]] ; then
 
-if [[ $DK_QTWEBENGINE = 0 ]] ; then
+    cp $ORIG_WD/data/qt.conf.qt5 "$TEMPROOT/digikam.app/Contents/Resources/qt.conf"
 
-    # Rules for QtWebKit runtime process
+else
 
-    mkdir -p $TEMPROOT/libexec/qt5/libexec/
-
-    # QtWebKit runtime process
-
-    [[ -e $INSTALL_PREFIX/libexec/qt5/libexec/QtWebNetworkProcess ]] && cp -a "$INSTALL_PREFIX/libexec/qt5/libexec/QtWebNetworkProcess" "$TEMPROOT/libexec/qt5/libexec/"
-    [[ -e $INSTALL_PREFIX/libexec/qt5/libexec/QtWebProcess ]]        && cp -a "$INSTALL_PREFIX/libexec/qt5/libexec/QtWebProcess"        "$TEMPROOT/libexec/qt5/libexec/"
-    [[ -e $INSTALL_PREFIX/libexec/qt5/libexec/QtWebStorageProcess ]] && cp -a "$INSTALL_PREFIX/libexec/qt5/libexec/QtWebStorageProcess" "$TEMPROOT/libexec/qt5/libexec/"
+    cp $ORIG_WD/data/qt.conf.qt6 "$TEMPROOT/digikam.app/Contents/Resources/qt.conf"
 
 fi
 
@@ -315,7 +358,7 @@ done
 
 # Move Qt translation data files at the right place in the bundle. See Bug #438701.
 
-mv -v $TEMPROOT/libexec/qt5/translations $TEMPROOT/digikam.app/Contents/Resources/
+mv -v $TEMPROOT/libexec/qt$DK_QTVERSION/translations $TEMPROOT/digikam.app/Contents/Resources/
 
 # To support localized system menu entries from MacOS. See bug #432650.
 
@@ -335,13 +378,13 @@ rm -rf "$TEMPROOT/showfoto.app/Contents/Resources"
 cd "$ORIG_WD"
 
 #################################################################################################
-# Move digiKam and KF5 run-time plugins to the right place
+# Move digiKam and KF run-time plugins to the right place
 
-cp -a $TEMPROOT/lib/plugins $TEMPROOT/libexec/qt5/
+cp -a $TEMPROOT/lib/plugins $TEMPROOT/libexec/qt$DK_QTVERSION/
 rm -rf $TEMPROOT/lib/plugins
 
 # See bug #476290
-rm -fr $TEMPROOT/libexec/qt5/plugins/imageformats/libqjp2.dylib
+rm -fr $TEMPROOT/libexec/qt$DK_QTVERSION/plugins/imageformats/libqjp2.dylib
 
 #################################################################################################
 # Merge Manifest files
@@ -367,6 +410,9 @@ echo "---------- Create package pre-install script"
 cat << EOF > "$PROJECTDIR/preinstall"
 #!/bin/bash
 
+# This is the legacy install paths
+# TODO: remove this legacy rules in the future
+
 if [ -d /Applications/digiKam ] ; then
     echo "Removing digiKam directory from Applications folder"
     rm -r /Applications/digiKam
@@ -386,6 +432,15 @@ if [ -d "/opt/digikam" ] ; then
     echo "Removing legacy /opt/digikam"
     rm -rf "/opt/digikam"
 fi
+
+# NOTE: Use absolute path passed from the installer to store the relocatable application
+#       is stored in the env. var $DSTROOT
+
+if [ -d /Applications/digiKam.org ] ; then
+    echo "Removing digiKam.org from Applications folder"
+    rm -r /Applications/digiKam.org
+fi
+
 EOF
 
 # Pre-install script need to be executable
@@ -415,8 +470,18 @@ chmod 755 "$PROJECTDIR/postinstall"
 #################################################################################################
 # Copy icons-set resource files.
 
-cp $INSTALL_PREFIX/share/icons/breeze/breeze-icons.rcc           $TEMPROOT/digikam.app/Contents/Resources/breeze.rcc
-cp $INSTALL_PREFIX/share/icons/breeze-dark/breeze-icons-dark.rcc $TEMPROOT/digikam.app/Contents/Resources/breeze-dark.rcc
+# See https://bugs.kde.org/show_bug.cgi?id=487799#c54
+
+if [[ $DK_QTVERSION = 6 ]] ; then
+
+    cp $INSTALL_PREFIX/share/icons/breeze/breeze-icons.rcc $TEMPROOT/digikam.app/Contents/Resources/breeze.rcc
+
+else
+
+    cp $ORIG_WD/../common/breeze.rcc                        $TEMPROOT/digikam.app/Contents/Resources/breeze.rcc
+    cp $ORIG_WD/../common/breeze-dark.rcc                   $TEMPROOT/digikam.app/Contents/Resources/breeze-dark.rcc
+
+fi
 
 #################################################################################################
 # Cleanup symbols in binary files to free space.
@@ -535,6 +600,58 @@ ln -sv "../../digikam.app/Contents/libexec"   "$TEMPROOT/showfoto.app/Contents/l
 ln -sv "../../digikam.app/Contents/share"     "$TEMPROOT/showfoto.app/Contents/share"
 ln -sv "../../digikam.app/Contents/Resources" "$TEMPROOT/showfoto.app/Contents/Resources"
 
+# Specific plugin paths need to be linked in the bundle
+
+# For digiKam
+
+ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/designer"                      "$TEMPROOT/digikam.app/Contents/MacOS/designer"
+ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/generic"                       "$TEMPROOT/digikam.app/Contents/MacOS/generic"
+ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/imageformats"                  "$TEMPROOT/digikam.app/Contents/MacOS/imageformats"
+ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/platforms"                     "$TEMPROOT/digikam.app/Contents/MacOS/platforms"
+ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/styles"                        "$TEMPROOT/digikam.app/Contents/MacOS/styles"
+ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/iconengines"                   "$TEMPROOT/digikam.app/Contents/MacOS/iconengines"
+ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/sqldrivers"                    "$TEMPROOT/digikam.app/Contents/MacOS/sqldrivers"
+ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/kf$DK_QTVERSION"               "$TEMPROOT/digikam.app/Contents/MacOS/kf$DK_QTVERSION"
+
+if [[ $DK_QTVERSION = 6 ]] ; then
+
+    ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/multimedia"                "$TEMPROOT/digikam.app/Contents/MacOS/multimedia"
+    ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/tls"                       "$TEMPROOT/digikam.app/Contents/MacOS/tls"
+    ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/kiconthemes$DK_QTVERSION"  "$TEMPROOT/digikam.app/Contents/MacOS/kiconthemes$DK_QTVERSION"
+
+else
+
+    # Qt5 only
+
+    ln -sv "../../../digikam.app/Contents/libexec/qt$DK_QTVERSION/plugins/kauth"                     "$TEMPROOT/digikam.app/Contents/MacOS/kauth"
+
+fi
+
+# For Showfoto
+
+ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/designer"                     "$TEMPROOT/showfoto.app/Contents/MacOS/designer"
+ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/generic"                      "$TEMPROOT/showfoto.app/Contents/MacOS/generic"
+ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/imageformats"                 "$TEMPROOT/showfoto.app/Contents/MacOS/imageformats"
+ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/platforms"                    "$TEMPROOT/showfoto.app/Contents/MacOS/platforms"
+ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/styles"                       "$TEMPROOT/showfoto.app/Contents/MacOS/styles"
+ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/iconengines"                  "$TEMPROOT/showfoto.app/Contents/MacOS/iconengines"
+ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/sqldrivers"                   "$TEMPROOT/showfoto.app/Contents/MacOS/sqldrivers"
+ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/kf$DK_QTVERSION"              "$TEMPROOT/showfoto.app/Contents/MacOS/kf$DK_QTVERSION"
+
+if [[ $DK_QTVERSION = 6 ]] ; then
+
+    ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/multimedia"               "$TEMPROOT/showfoto.app/Contents/MacOS/multimedia"
+    ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/tls"                      "$TEMPROOT/showfoto.app/Contents/MacOS/tls"
+    ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/kiconthemes$DK_QTVERSION" "$TEMPROOT/showfoto.app/Contents/MacOS/kiconthemes$DK_QTVERSION"
+
+else
+
+    # Qt5 only
+
+    ln -sv "../../../showfoto.app/Contents/libexec/qt$DK_QTVERSION/plugins/kauth"                     "$TEMPROOT/showfoto.app/Contents/MacOS/kauth"
+
+fi
+
 echo -e "\n---------- Cleanup files in bundle"
 
 # Last cleanup
@@ -561,7 +678,7 @@ for DIR in ${MARIADBDIRS[@]} ; do
     for FILE in ${MARIADBFILES[@]} ; do
 
         # to handle only text files
-        ISTEXT=`file "$FILE" | grep "ASCII text" || true`
+        ISTEXT=`file "$FILE" | grep "text" || true`
 
         if [[ $ISTEXT ]] ; then
 
@@ -585,7 +702,7 @@ for DIR in ${MARIADBDIRS[@]} ; do
 done
 
 #################################################################################################
-# See bug #436624: move mariadb share files at basedir (this must be done after patch operations)
+# See bug #436624: move mariadb shared files at basedir (this must be done after patch operations)
 
 rsync -a "$TEMPROOT/digikam.app/Contents/share/mariadb$MARIADB_SUFFIX" "$TEMPROOT/digikam.app/Contents/lib/mariadb$MARIADB_SUFFIX/share/"
 rm -fr "$TEMPROOT/digikam.app/Contents/share/mariadb$MARIADB_SUFFIX"
@@ -596,6 +713,8 @@ ln -sv "../../../../../digikam.app/Contents/lib/mariadb$MARIADB_SUFFIX/share/mar
 ln -sv "../../../digikam.app/Contents/lib/mariadb$MARIADB_SUFFIX"                                    "$TEMPROOT/digikam.app/Contents/lib/mariadb"
 ln -sv "../../../digikam.app/Contents/etc/mariadb$MARIADB_SUFFIX"                                    "$TEMPROOT/digikam.app/Contents/etc/mariadb"
 
+ln -sv "../../../../digikam.app/Contents/lib/mariadb$MARIADB_SUFFIX"                                 "$TEMPROOT/digikam.app/Contents/lib/mariadb/lib"
+
 #################################################################################################
 # Install ExifTool binary.
 
@@ -617,7 +736,7 @@ ln -sv "./Image-ExifTool/exiftool" "exiftool"
 echo "---------- Create MacOS package for digiKam $DKRELEASEID"
 
 mkdir -p $ORIG_WD/bundle
-rm -f $ORIG_WD/bundle/*x86-64$DEBUG_SUF* || true
+rm -f $ORIG_WD/bundle/*$DEBUG_SUF* || true
 
 if [[ $DK_VERSION != v* ]] ; then
 
@@ -632,7 +751,17 @@ else
 
 fi
 
-TARGET_INSTALLER=digiKam-$DKRELEASEID$DK_SUBVER-MacOS-x86-64$DEBUG_SUF.pkg
+if [[ $DK_QTVERSION == 5 ]] ; then
+
+    QT_SUF="-Qt5"
+
+else
+
+    QT_SUF="-Qt6"
+
+fi
+
+TARGET_INSTALLER=digiKam-$DKRELEASEID$DK_SUBVER$QT_SUF-MacOS-$ARCH_TARGET$DEBUG_SUF.pkg
 TARGET_PKG_FILE=$BUILDDIR/bundle/$TARGET_INSTALLER
 echo -e "Target PKG file : $TARGET_PKG_FILE"
 
@@ -677,7 +806,7 @@ if [[ $DK_UPLOAD = 1 ]] ; then
 
     echo -e "---------- Cleanup older bundle Package files from files.kde.org repository \n"
 
-    sftp -q $DK_UPLOADURL:$DK_UPLOADDIR <<< "rm *-MacOS-x86-64$DEBUG_SUF.pkg*"
+    sftp -q $DK_UPLOADURL:$DK_UPLOADDIR <<< "rm *-MacOS*$DEBUG_SUF.pkg*"
 
     echo -e "---------- Upload new bundle Package files to files.kde.org repository \n"
 
