@@ -16,7 +16,7 @@ BUILDING_DIR="`pwd`/temp.build"
 ########################################################################
 
 # Target macOS architecture: "x86_64" for Intel 64 bits, or "arm64" for Apple Silicon 64 bits.
-ARCH_TARGET="x86_64"
+ARCH_TARGET="`uname -m`"
 
 if [[ $ARCH_TARGET = "x86_64" ]] ; then
 
@@ -50,7 +50,7 @@ if [[ $ARCH_TARGET = "x86_64" ]] ; then
 elif [[ $ARCH_TARGET = "arm64" ]] ; then
 
     # Apple Silicon is supported since macOS BigSur
-    OSX_MIN_TARGET="11.0"
+    OSX_MIN_TARGET="11.3"
 
 else
 
@@ -59,6 +59,8 @@ else
 
 fi
 
+echo "Target Architecture: $ARCH_TARGET"
+
 # Directory to build and install Macports packages.
 INSTALL_PREFIX="/opt/digikam.org.$ARCH_TARGET"
 # Local install prefix which do not require sudo right
@@ -88,52 +90,73 @@ DK_URL="http://download.kde.org/stable/digikam"
 # Location to build source code.
 DK_BUILDTEMP=~/dktemp
 
-# KDE Plasma version.
-# See official release here: https://download.kde.org/stable/plasma/
-DK_KP_VERSION="5.27.10"
-
-# KDE Application version.
-# See official release here: https://download.kde.org/stable/release-service/
-DK_KA_VERSION="23.08.4"
-
-# KDE KF5 frameworks version.
-# See official release here: https://download.kde.org/stable/frameworks/
-DK_KDE_VERSION="5.114"
-
 # Qt version to use in bundle and provided by Macports.
-DK_QTVERSION="5"
+#DK_QTVERSION="5"
+DK_QTVERSION="6"
 
-# Mariadb version to install for Qt QSL plugin.
-# Left empty to use current 5.x from Macports
-DK_MARIADB_VERSION=""
-#DK_MARIADB_VERSION="10.5"
+# Mariadb version to install for Qt SQL plugin.
+DK_MARIADB_VERSION="10.11"
 
-if [[ ! -z "$DK_MARIADB_VERSION" ]] ; then
-    MP_MARIADB_VARIANT="+mariadb$DK_MARIADB_VERSION"
-    MP_MARIADB_VARIANT=${MP_MARIADB_VARIANT//./_}
-    MARIADB_SUFFIX="-$DK_MARIADB_VERSION"
-fi
+MP_MARIADB_VARIANT="+mariadb$DK_MARIADB_VERSION"
+MP_MARIADB_VARIANT=${MP_MARIADB_VARIANT//./_}
+MARIADB_SUFFIX="-$DK_MARIADB_VERSION"
 
 # digiKam tag version from git. Official tarball do not include extra shared libraries.
 # The list of tags can be listed with this url: https://invent.kde.org/graphics/digikam/-/tags
 # If you want to package current implementation from git, use "master" as tag.
-#DK_VERSION=v7.2.0-beta1
+#DK_VERSION=v8.4.0
 DK_VERSION=master
 #DK_VERSION=development/dplugins
 
 # Installer sub version to differentiates newer updates of the installer itself, even if the underlying application hasn’t changed.
 #DK_SUBVER="-01"
 
+# needed to separate Macports from Homebrew
+DK_APPLE_PACKAGE_MANAGER="macports"
+
 # Installer will include or not digiKam debug symbols
 DK_DEBUG=0
 
-# Option to use QtWebEngine instead QtWebkit
-DK_QTWEBENGINE=1
-
 # Sign bundles with GPG. Passphrase must be hosted in ~/.gnupg/dkorg-gpg-pwd.txt
 DK_SIGN=0
 
 # Upload automatically bundle to files.kde.org (pre-release only).
 DK_UPLOAD=1
 DK_UPLOADURL="digikam@tinami.kde.org"
-DK_UPLOADDIR="/srv/archives/files/digikam/"
+
+# KDE frameworks version + Upload URL.
+# See official release here: https://download.kde.org/stable/frameworks/
+
+if [[ $DK_QTVERSION == 5 ]] ; then
+
+    # KDE Plasma version.
+    # See official release here: https://download.kde.org/stable/plasma/
+    DK_KDE_VERSION="5.116"
+
+    # KDE Application version.
+    # See official release here: https://download.kde.org/stable/release-service/
+    DK_KP_VERSION="5.27.11"
+
+    # KDE KF6 frameworks version.
+    # See official release here: https://download.kde.org/stable/frameworks/
+    DK_KA_VERSION="24.05.1"
+
+    DK_UPLOADDIR="/srv/archives/files/digikam/legacy"
+
+else
+
+    # KDE Plasma version.
+    # See official release here: https://download.kde.org/stable/plasma/
+    DK_KP_VERSION="v6.2.1"
+
+    # KDE Application version.
+    # See official release here: https://download.kde.org/stable/release-service/
+    DK_KA_VERSION="v24.08.2"
+
+    # KDE KF6 frameworks version.
+    # See official release here: https://download.kde.org/stable/frameworks/
+    DK_KDE_VERSION="v6.7.0"
+
+    DK_UPLOADDIR="/srv/archives/files/digikam/"
+
+fi
